@@ -463,8 +463,8 @@ public class SVNCommandUtil {
         }
         if (!quiet) {
             message += 
-                "\nCopyright (c) 2004-2016 TMate Software.\n" +
-                "SVNKit is an Open Source software, see http://svnkit.com/ for more information.\n" +
+                "\nCopyright (c) 2004-2021 TMate Software.\n" +
+                "SVNKit is an Open Source software, see https://svnkit.com/ for more information.\n" +
                 "SVNKit is a pure Java (TM) version of Subversion, see http://subversion.tigris.org/";
         }
         return message;
