@@ -146,6 +146,7 @@ public class SVN extends AbstractSVNLauncher {
         SVNCommandLine.registerOption(SVNOption.ALLOW_MIXED_REVISIONS);
         SVNCommandLine.registerOption(SVNOption.DIFF_CMD);
         SVNCommandLine.registerOption(SVNOption.TRUST_SERVER_CERT);
+        SVNCommandLine.registerOption(SVNOption.TRUST_SERVER_CERT_FAILURES);
         SVNCommandLine.registerOption(SVNOption.CONFIG_OPTION);
 
         SVNCommandLine.registerOption(SVNOption.STRIP);
@@ -155,6 +156,11 @@ public class SVN extends AbstractSVNLauncher {
         SVNCommandLine.registerOption(SVNOption.IGNORE_PROPERTIES);
         SVNCommandLine.registerOption(SVNOption.REVERSE_DIFF);
         SVNCommandLine.registerOption(SVNOption.IGNORE_WHITESPACE);
+        SVNCommandLine.registerOption(SVNOption.SHOW_ITEM);
+        SVNCommandLine.registerOption(SVNOption.NO_NEWLINE);
+        SVNCommandLine.registerOption(SVNOption.PIN_EXTERNALS);
+        SVNCommandLine.registerOption(SVNOption.REMOVE_UNVERSIONED);
+        SVNCommandLine.registerOption(SVNOption.REMOVE_IGNORED);
 
     }
 
