@@ -19,29 +19,16 @@ import java.io.InputStream;
 import java.io.OutputStream;
 import java.io.PrintStream;
 import java.io.UnsupportedEncodingException;
-import java.util.Arrays;
-import java.util.Collection;
-import java.util.Collections;
-import java.util.HashMap;
-import java.util.Iterator;
-import java.util.LinkedList;
-import java.util.List;
-import java.util.Map;
-import java.util.StringTokenizer;
+import java.util.*;
 
-import org.tmatesoft.svn.cli.AbstractSVNCommand;
-import org.tmatesoft.svn.cli.AbstractSVNCommandEnvironment;
-import org.tmatesoft.svn.cli.AbstractSVNOption;
-import org.tmatesoft.svn.cli.SVNCommandLine;
-import org.tmatesoft.svn.cli.SVNCommandUtil;
-import org.tmatesoft.svn.cli.SVNConsoleAuthenticationProvider;
-import org.tmatesoft.svn.cli.SVNOptionValue;
+import org.tmatesoft.svn.cli.*;
 import org.tmatesoft.svn.core.SVNDepth;
 import org.tmatesoft.svn.core.SVNErrorCode;
 import org.tmatesoft.svn.core.SVNErrorMessage;
 import org.tmatesoft.svn.core.SVNException;
 import org.tmatesoft.svn.core.SVNProperties;
 import org.tmatesoft.svn.core.auth.ISVNAuthenticationManager;
+import org.tmatesoft.svn.core.internal.util.SVNCertificateFailureKind;
 import org.tmatesoft.svn.core.internal.util.SVNHashSet;
 import org.tmatesoft.svn.core.internal.wc.DefaultSVNAuthenticationManager;
 import org.tmatesoft.svn.core.internal.wc.DefaultSVNOptions;
@@ -130,7 +117,8 @@ public class SVNCommandEnvironment extends AbstractSVNCommandEnvironment impleme
     private boolean myIsRevisionOptionUsed;
     private boolean myIsWithAllRevprops;
     private boolean myIsReIntegrate;
-    private boolean myIsTrustServerCertificate;
+    private boolean myIsTrustServerCertificate; //since 1.9 this is an equivalent of myIsTrustServerCertificate.contains(UNKNOWN_CA)
+    private EnumSet<SVNCertificateFailureKind> myIsTrustServerCertificateFailures;
     private boolean myIsAllowMixedRevisions;
     private List myRevisionRanges;
     private SVNShowRevisionType myShowRevsType;
@@ -149,6 +137,11 @@ public class SVNCommandEnvironment extends AbstractSVNCommandEnvironment impleme
     private int myStripCount;
     private boolean myIsShowInhertiedProps;
     private boolean myIsIncludeExternals;
+    private String myShowItem;
+    private boolean myIsNoNewLine;
+    private boolean myIsPinExternals;
+    private boolean myIsRemoveUnversioned;
+    private boolean myIsRemoveIgnored;
 
     private SVNConflictStats myConflictStats;
 
@@ -259,7 +252,7 @@ public class SVNCommandEnvironment extends AbstractSVNCommandEnvironment impleme
         final ISVNAuthStoreHandler authStoreHandler;
         final ISVNGnomeKeyringPasswordProvider gnomeKeyringPasswordProvider;
         if (!myIsNonInteractive) {
-            SVNConsoleAuthenticationProvider consoleAuthProvider = new SVNConsoleAuthenticationProvider(myIsTrustServerCertificate);
+            SVNConsoleAuthenticationProvider consoleAuthProvider = new SVNConsoleAuthenticationProvider(myIsTrustServerCertificateFailures);
             authManager.setAuthenticationProvider(consoleAuthProvider);
             authStoreHandler = consoleAuthProvider;
             gnomeKeyringPasswordProvider = consoleAuthProvider;
@@ -348,6 +341,12 @@ public class SVNCommandEnvironment extends AbstractSVNCommandEnvironment impleme
             SVNErrorMessage err = SVNErrorMessage.create(SVNErrorCode.CL_ARG_PARSING_ERROR, "--trust-server-cert requires --non-interactive");
             SVNErrorManager.error(err, SVNLogType.CLIENT);
         }
+
+        if (myIsTrustServerCertificateFailures != null && myIsTrustServerCertificateFailures.size() > 0 && !myIsNonInteractive) {
+            SVNErrorMessage errorMessage = SVNErrorMessage.create(SVNErrorCode.CL_ARG_PARSING_ERROR, "--trust-server-cert-failures requires " +
+                    "--non-interactive");
+            SVNErrorManager.error(errorMessage, SVNLogType.WC);
+        }
     }
     
     protected void initOption(SVNOptionValue optionValue) throws SVNException {
@@ -667,8 +666,42 @@ public class SVNCommandEnvironment extends AbstractSVNCommandEnvironment impleme
             myRegularExpression = optionValue.getValue();
         } else if (option == SVNOption.TRUST_SERVER_CERT) {
             myIsTrustServerCertificate = true;
+            myIsTrustServerCertificateFailures = EnumSet.of(SVNCertificateFailureKind.UNKNOWN_CA);
+        } else if (option == SVNOption.TRUST_SERVER_CERT_FAILURES) {
+            myIsTrustServerCertificateFailures = EnumSet.noneOf(SVNCertificateFailureKind.class);
+
+            String failuesCommaSeparated = optionValue.getValue();
+            if (failuesCommaSeparated != null) {
+                String[] failures = failuesCommaSeparated.split(",");
+                for (String failure : failures) {
+                    failure = failure.trim();
+                    if (failure.length() > 0) {
+                        SVNCertificateFailureKind failureKind = SVNCertificateFailureKind.fromString(failure);
+                        if (failureKind != null) {
+                            myIsTrustServerCertificateFailures.add(failureKind);
+                        } else {
+                            SVNErrorMessage errorMessage = SVNErrorMessage.create(SVNErrorCode.CL_ARG_PARSING_ERROR, "Unknown value ''{0}'' for {1}.\n" +
+                                    "Supported values: {2}", new Object[]{failure,
+                                    "--trust-server-cert-failures",
+                                    "unknown-ca, cn-mismatch, expired, " +
+                                    "not-yet-valid, other"});
+                            SVNErrorManager.error(errorMessage, SVNLogType.WC);
+                        }
+                    }
+                }
+            }
         } else if (option == SVNOption.SHOW_INHERITED_PROPS) {
             myIsShowInhertiedProps = true;
+        } else if (option == SVNOption.PIN_EXTERNALS) {
+            myIsPinExternals = true;
+        } else if (option == SVNOption.REMOVE_UNVERSIONED) {
+            myIsRemoveUnversioned = true;
+        } else if (option == SVNOption.REMOVE_IGNORED) {
+            myIsRemoveIgnored = true;
+        } else if (option == SVNOption.NO_NEWLINE) {
+            myIsNoNewLine = true;
+        } else if (option == SVNOption.SHOW_ITEM) {
+            myShowItem = optionValue.getValue();
         } else if (option == SVNOption.INCLUDE_EXTERNALS) {
             myIsIncludeExternals = true;
         } else if(option == SVNOption.STRIP ) {
@@ -1025,6 +1058,26 @@ public class SVNCommandEnvironment extends AbstractSVNCommandEnvironment impleme
         return myIsShowInhertiedProps;
     }
 
+    public String getShowItem() {
+        return myShowItem;
+    }
+
+    public boolean isNoNewLine() {
+        return myIsNoNewLine;
+    }
+
+    public boolean isPinExternals() {
+        return myIsPinExternals;
+    }
+
+    public boolean isRemoveUnversioned() {
+        return myIsRemoveUnversioned;
+    }
+
+    public boolean isRemoveIgnored() {
+        return myIsRemoveIgnored;
+    }
+
     public boolean isIncludeExternals() {
         return myIsIncludeExternals;
     }
