@@ -55,7 +55,7 @@ public class SVNErrorCode implements Serializable {
      * @return a corresponding <b>SVNErrorCode</b>.
      */
     public static SVNErrorCode getErrorCode(int code) {
-        SVNErrorCode errorCode = (SVNErrorCode) ourErrorCodes.get(new Integer(code));
+        SVNErrorCode errorCode = (SVNErrorCode) ourErrorCodes.get(code);
         if (errorCode == null) {
             errorCode = UNKNOWN;
         }
@@ -66,7 +66,7 @@ public class SVNErrorCode implements Serializable {
         myCategory = category;
         myCode = category + index;
         myDescription = description;
-        ourErrorCodes.put(new Integer(myCode), this);
+        ourErrorCodes.put(myCode, this);
     }
     
     /**
@@ -131,7 +131,7 @@ public class SVNErrorCode implements Serializable {
     }
     
     private Object readResolve() {
-        return ourErrorCodes.get(new Integer(myCode));
+        return ourErrorCodes.get(myCode);
     }
     
     /**
@@ -647,7 +647,68 @@ public class SVNErrorCode implements Serializable {
      * @since  1.3, SVN 1.6
      */
     public static final SVNErrorCode UNSUPPORTED_SCHEMA = new SVNErrorCode(MISC_CATEGORY, 32, "Unsupported schema found in SQLite db");
-    
+    /**
+     * @since  1.3, SVN 1.7
+     */
+    public static final SVNErrorCode SQLITE_BUSY = new SVNErrorCode(MISC_CATEGORY, 33, "The SQLite db is busy");
+    /**
+     * @since  1.3, SVN 1.7
+     */
+    public static final SVNErrorCode SQLITE_RESETTING_FOR_ROLLBACK = new SVNErrorCode(MISC_CATEGORY, 34, "SQLite busy at transaction rollback; " +
+            "resetting all busy SQLite statements to allow rollback");
+    /**
+     * @since  1.3, SVN 1.7
+     */
+    public static final SVNErrorCode SQLITE_CONSTRAINT = new SVNErrorCode(MISC_CATEGORY, 35, "Constraint error in SQLite db");
+    /**
+     * @since  1.3, SVN 1.8
+     */
+    public static final SVNErrorCode TOO_MANY_MEMCACHED_SERVERS = new SVNErrorCode(MISC_CATEGORY, 36, "Too many memcached servers configured");
+    /**
+     * @since  1.3, SVN 1.8
+     */
+    public static final SVNErrorCode MALFORMED_VERSION_STRING = new SVNErrorCode(MISC_CATEGORY, 37, "Failed to parse version number string");
+    /**
+     * @since  1.3, SVN 1.8
+     */
+    public static final SVNErrorCode CORRUPTED_ATOMIC_STORAGE = new SVNErrorCode(MISC_CATEGORY, 38, "Atomic data storage is corrupt");
+    /**
+     * @since  1.3, SVN 1.8
+     */
+    public static final SVNErrorCode UTF8PROC_ERROR = new SVNErrorCode(MISC_CATEGORY, 39, "utf8proc library error");
+    /**
+     * @since  1.3, SVN 1.8
+     */
+    public static final SVNErrorCode UTF8_GLOB = new SVNErrorCode(MISC_CATEGORY, 40, "Bad arguments to SQL operators GLOB or LIKE");
+    /**
+     * @since  1.3, SVN 1.9
+     */
+    public static final SVNErrorCode CORRUPT_PACKED_DATA = new SVNErrorCode(MISC_CATEGORY, 41, "Packed data stream is corrupt");
+    /**
+     * @since  1.3, SVN 1.9
+     */
+    public static final SVNErrorCode COMPOSED_ERROR = new SVNErrorCode(MISC_CATEGORY, 42, "Additional errors:");
+    /**
+     * @since  1.3, SVN 1.9
+     */
+    public static final SVNErrorCode INVALID_INPUT = new SVNErrorCode(MISC_CATEGORY, 43, "Parser error: invalid input");
+    /**
+     * @since  1.3, SVN 1.10
+     */
+    public static final SVNErrorCode SQLITE_ROLLBACK_FAILED = new SVNErrorCode(MISC_CATEGORY, 44, "SQLite transaction rollback failed");
+    /**
+     * @since  1.3, SVN 1.10
+     */
+    public static final SVNErrorCode LZ4_COMPRESSION_FAILED = new SVNErrorCode(MISC_CATEGORY, 45, "LZ4 compression failed");
+    /**
+     * @since  1.3, SVN 1.10
+     */
+    public static final SVNErrorCode LZ4_DECOMPRESSION_FAILED = new SVNErrorCode(MISC_CATEGORY, 46, "LZ4 decompression failed");
+
+
+
+
+
     public static final SVNErrorCode CL_ARG_PARSING_ERROR = new SVNErrorCode(CL_CATEGORY, 0, "Client error in parsing arguments");
     public static final SVNErrorCode CL_INSUFFICIENT_ARGS = new SVNErrorCode(CL_CATEGORY, 1, "Not enough args provided");
     public static final SVNErrorCode CL_MUTUALLY_EXCLUSIVE_ARGS = new SVNErrorCode(CL_CATEGORY, 2, "Mutually exclusive arguments specified");
