@@ -12,36 +12,27 @@
 
 package org.tmatesoft.svn.core.internal.io.dav;
 
-import java.io.ByteArrayInputStream;
-import java.io.InputStream;
-import java.io.OutputStream;
-import java.net.HttpURLConnection;
-import java.util.*;
-
-import org.tmatesoft.svn.core.SVNErrorCode;
-import org.tmatesoft.svn.core.SVNErrorMessage;
-import org.tmatesoft.svn.core.SVNException;
-import org.tmatesoft.svn.core.SVNLock;
-import org.tmatesoft.svn.core.SVNProperty;
-import org.tmatesoft.svn.core.SVNPropertyValue;
-import org.tmatesoft.svn.core.SVNURL;
+import org.tmatesoft.svn.core.*;
 import org.tmatesoft.svn.core.internal.io.dav.handlers.DAVGetLocksHandler;
 import org.tmatesoft.svn.core.internal.io.dav.handlers.DAVLockHandler;
 import org.tmatesoft.svn.core.internal.io.dav.handlers.DAVMergeHandler;
 import org.tmatesoft.svn.core.internal.io.dav.handlers.DAVOptionsHandler;
-import org.tmatesoft.svn.core.internal.io.dav.http.HTTPConnection;
-import org.tmatesoft.svn.core.internal.io.dav.http.HTTPHeader;
-import org.tmatesoft.svn.core.internal.io.dav.http.HTTPStatus;
-import org.tmatesoft.svn.core.internal.io.dav.http.IHTTPConnection;
-import org.tmatesoft.svn.core.internal.io.dav.http.IHTTPConnectionFactory;
+import org.tmatesoft.svn.core.internal.io.dav.http.*;
 import org.tmatesoft.svn.core.internal.util.*;
 import org.tmatesoft.svn.core.internal.wc.SVNErrorManager;
 import org.tmatesoft.svn.core.io.ISVNWorkspaceMediator;
 import org.tmatesoft.svn.core.io.SVNCapability;
 import org.tmatesoft.svn.core.io.SVNRepository;
+import org.tmatesoft.svn.core.wc.SVNRevision;
 import org.tmatesoft.svn.util.SVNLogType;
 import org.xml.sax.helpers.DefaultHandler;
 
+import java.io.ByteArrayInputStream;
+import java.io.InputStream;
+import java.io.OutputStream;
+import java.net.HttpURLConnection;
+import java.util.*;
+
 
 /**
  * @version 1.3
@@ -106,7 +97,12 @@ public class DAVConnection {
         myActivityCollectionURL = null;
     }
 
+
     public void open(DAVRepository repository) throws SVNException {
+        open(repository, null);
+    }
+
+    public void open(DAVRepository repository, SVNURL[] correctedUrl) throws SVNException {
         if (myHttpConnection == null) {
             myHttpConnection = myConnectionFactory.createHTTPConnection(repository);
             if (repository.getSpoolLocation() != null) {
@@ -115,7 +111,7 @@ public class DAVConnection {
                     ((HTTPConnection) myHttpConnection).setSpoolDirectory(repository.getSpoolLocation());
                 }
             }
-            exchangeCapabilities();
+            exchangeCapabilities(correctedUrl);
         }
     }
 
@@ -210,13 +206,18 @@ public class DAVConnection {
         return handler.getLocks();
     }
 
-    public SVNLock doLock(String repositoryPath, String path, DAVRepository repos, String comment, boolean force, long revision) throws SVNException {
+    public SVNLock doLock(String repositoryPath, String path, DAVRepository repos, String comment, boolean force, long revision,
+                          long timeout) throws SVNException {
         beforeCall();
 
         StringBuffer body = DAVLockHandler.generateSetLockRequest(null, comment);
         HTTPHeader header = new HTTPHeader();
         header.setHeaderValue(HTTPHeader.DEPTH_HEADER, "0");
-        header.setHeaderValue(HTTPHeader.TIMEOUT_HEADER, "Infinite");
+        if (timeout <= 0) {
+            header.setHeaderValue(HTTPHeader.TIMEOUT_HEADER, "Infinite");
+        } else {
+            header.setHeaderValue(HTTPHeader.TIMEOUT_HEADER, "Second-" + Long.toString(timeout));
+        }
         header.setHeaderValue(HTTPHeader.CONTENT_TYPE_HEADER, "text/xml; charset=\"utf-8\"");
 
         if (revision >= 0) {
@@ -240,6 +241,10 @@ public class DAVConnection {
                 SVNErrorMessage err = SVNErrorMessage.create(SVNErrorCode.FS_OUT_OF_DATE, "Lock request failed: {0} {1}",
                         new Object[] {myLastStatus.getCode(), myLastStatus.getReason()});
                 SVNErrorManager.error(err, SVNLogType.CLIENT);
+            } else if (myLastStatus.getCode() == 403) {
+                SVNErrorManager.error(
+                        SVNErrorMessage.create(SVNErrorCode.RA_DAV_FORBIDDEN, "Lock request failed failed on ''{0}'' (403 Forbidden)", path),
+                        SVNLogType.NETWORK);
             }
             if (myLastStatus.getError() != null) {
                 myLastStatus.getError().setChildErrorMessage(null); //  subversion doesn't have a child message for lock
@@ -520,7 +525,7 @@ public class DAVConnection {
         return performHttpRequest(httpConnection, "MKCOL", path, null, (StringBuffer) null, 201, 0, null, null);
     }
 
-    public HTTPStatus doPutDiff(String repositoryPath, String path, InputStream data, long size, String baseChecksum, String textChecksum) throws SVNException {
+    public HTTPStatus doPutDiff(String repositoryPath, String path, InputStream data, long size, String baseChecksum, String textChecksum, long baseRevision) throws SVNException {
         beforeCall();
         HTTPHeader headers = new HTTPHeader();
         headers.setHeaderValue(HTTPHeader.CONTENT_TYPE_HEADER, HTTPHeader.SVNDIFF_MIME_TYPE);
@@ -528,6 +533,9 @@ public class DAVConnection {
         if (myLocks != null && myLocks.containsKey(repositoryPath)) {
             headers.setHeaderValue(HTTPHeader.IF_HEADER, "<" + repositoryPath + "> (<" + myLocks.get(repositoryPath) + ">)");
         }
+        if (SVNRevision.isValidRevisionNumber(baseRevision)) {
+            headers.setHeaderValue(HTTPHeader.SVN_VERSION_NAME_HEADER, String.valueOf(baseRevision));
+        }
         if (baseChecksum != null) {
             headers.setHeaderValue(HTTPHeader.BASE_MD5, baseChecksum);
         }
@@ -651,7 +659,7 @@ public class DAVConnection {
 
     public String getCapabilityResponse(SVNCapability capability) throws SVNException {
     	if (myCapabilities == null || myCapabilities.get(capability) == null) {
-    		exchangeCapabilities();
+    		exchangeCapabilities(null);
     	}
         return (String) myCapabilities.get(capability);
     }
@@ -692,17 +700,48 @@ public class DAVConnection {
         return myHttpConnection;
     }
 
-    protected void exchangeCapabilities() throws SVNException {
+    protected void exchangeCapabilities(SVNURL[] correctedUrl) throws SVNException {
         String path = SVNEncodingUtil.uriEncode(getLocation().getPath());
         IHTTPConnection httpConnection = getConnection();
         HTTPStatus status = performHttpRequest(httpConnection, "OPTIONS", path, null, DAVOptionsHandler.OPTIONS_REQUEST, 200, 0, null, null);
+
+        if (DAVRepository.ourRedirectsEnabled && correctedUrl != null && status.getCode() == 301) {
+            final String newLocation = status.getHeader().getFirstHeaderValue(HTTPHeader.LOCATION_HEADER);
+            if (newLocation == null || newLocation.length() == 0) {
+                final SVNErrorMessage errorMessage = SVNErrorMessage.create(SVNErrorCode.RA_DAV_RESPONSE_HEADER_BADNESS, "Location header not set on redirect response");
+                SVNErrorManager.error(errorMessage, SVNLogType.NETWORK);
+            } else if (SVNPathUtil.isURL(newLocation)) {
+                correctedUrl[0] = SVNURL.parseURIEncoded(newLocation);
+            } else {
+                final SVNURL currentLocation = getLocation();
+                correctedUrl[0] = SVNURL.create(currentLocation.getProtocol(), currentLocation.getUserInfo(), currentLocation.getHost(), currentLocation.getPort(),
+                        newLocation, /*URI encoded*/false);
+            }
+            return;
+        } else if (status.getCode() >= 300 && status.getCode() < 399) {
+            final String location = status.getHeader() != null ? status.getHeader().getFirstHeaderValue("Location") : null;
+
+            String message;
+            SVNErrorMessage errorMessage;
+            if (location != null) {
+                message = status.getCode() == HttpURLConnection.HTTP_MOVED_PERM ? "Repository moved permanently to ''{0}''; please relocate" :
+                        "Repository moved temporarily to ''{0}''; please relocate";
+                errorMessage = SVNErrorMessage.create(SVNErrorCode.RA_DAV_RELOCATED, message, location);
+            } else {
+                message = status.getCode() == HttpURLConnection.HTTP_MOVED_PERM ? "Repository moved permanently; please relocate" :
+                        "Repository moved temporarily; please relocate";
+                errorMessage = SVNErrorMessage.create(SVNErrorCode.RA_DAV_RELOCATED, message);
+            }
+            SVNErrorManager.error(errorMessage, SVNLogType.NETWORK);
+        }
+
         if (status.getCode() == 200) {
-        	parseCapabilities(status);
+            parseCapabilities(status);
         } else {
-        	SVNErrorMessage err = SVNErrorMessage.create(SVNErrorCode.RA_DAV_OPTIONS_REQ_FAILED,
-        			"OPTIONS request (for capabilities) got HTTP response code {0}",
-        			new Integer(status.getCode()));
-        	SVNErrorManager.error(err, SVNLogType.NETWORK);
+            SVNErrorMessage err = SVNErrorMessage.create(SVNErrorCode.RA_DAV_OPTIONS_REQ_FAILED,
+                    "OPTIONS request (for capabilities) got HTTP response code {0}",
+                    new Object[]{status.getCode()});
+            SVNErrorManager.error(err, SVNLogType.NETWORK);
         }
     }
 
@@ -725,21 +764,25 @@ public class DAVConnection {
         Collection capValues = header.getHeaderValues(HTTPHeader.DAV_HEADER);
     	if (capValues != null) {
     		for (Iterator valuesIter = capValues.iterator(); valuesIter.hasNext();) {
-                String value = (String) valuesIter.next();
-    			if (DAVElement.DEPTH_OPTION.equalsIgnoreCase(value)) {
-    				myCapabilities.put(SVNCapability.DEPTH, DAV_CAPABILITY_YES);
-    			} else if (DAVElement.MERGE_INFO_OPTION.equalsIgnoreCase(value)) {
-    				myCapabilities.put(SVNCapability.MERGE_INFO, DAV_CAPABILITY_SERVER_YES);
-    			} else if (DAVElement.LOG_REVPROPS_OPTION.equalsIgnoreCase(value)) {
-    				myCapabilities.put(SVNCapability.LOG_REVPROPS, DAV_CAPABILITY_YES);
-    			} else if (DAVElement.PARTIAL_REPLAY_OPTION.equalsIgnoreCase(value)) {
-    				myCapabilities.put(SVNCapability.PARTIAL_REPLAY, DAV_CAPABILITY_YES);
-    			} else if (DAVElement.ATOMIC_REVPROPS_OPTION.equalsIgnoreCase(value)) {
-                    myCapabilities.put(SVNCapability.ATOMIC_REVPROPS, DAV_CAPABILITY_YES);
-                } else if (DAVElement.INHERITED_PROPS_OPTION.equalsIgnoreCase(value)) {
-                    myCapabilities.put(SVNCapability.INHERITED_PROPS, DAV_CAPABILITY_YES);
-                } else if (DAVElement.EPHEMERAL_PROPS_OPTION.equalsIgnoreCase(value)) {
-                    myCapabilities.put(SVNCapability.EPHEMERAL_PROPS, DAV_CAPABILITY_YES);
+                String values = (String) valuesIter.next();
+                final String[] valuesArray = values.split(",");
+                for (String value : valuesArray) {
+                    value = value.trim();
+                    if (DAVElement.DEPTH_OPTION.equalsIgnoreCase(value)) {
+                        myCapabilities.put(SVNCapability.DEPTH, DAV_CAPABILITY_YES);
+                    } else if (DAVElement.MERGE_INFO_OPTION.equalsIgnoreCase(value)) {
+                        myCapabilities.put(SVNCapability.MERGE_INFO, DAV_CAPABILITY_SERVER_YES);
+                    } else if (DAVElement.LOG_REVPROPS_OPTION.equalsIgnoreCase(value)) {
+                        myCapabilities.put(SVNCapability.LOG_REVPROPS, DAV_CAPABILITY_YES);
+                    } else if (DAVElement.PARTIAL_REPLAY_OPTION.equalsIgnoreCase(value)) {
+                        myCapabilities.put(SVNCapability.PARTIAL_REPLAY, DAV_CAPABILITY_YES);
+                    } else if (DAVElement.ATOMIC_REVPROPS_OPTION.equalsIgnoreCase(value)) {
+                        myCapabilities.put(SVNCapability.ATOMIC_REVPROPS, DAV_CAPABILITY_YES);
+                    } else if (DAVElement.INHERITED_PROPS_OPTION.equalsIgnoreCase(value)) {
+                        myCapabilities.put(SVNCapability.INHERITED_PROPS, DAV_CAPABILITY_YES);
+                    } else if (DAVElement.EPHEMERAL_PROPS_OPTION.equalsIgnoreCase(value)) {
+                        myCapabilities.put(SVNCapability.EPHEMERAL_PROPS, DAV_CAPABILITY_YES);
+                    }
                 }
 			}
     	}
@@ -748,8 +791,11 @@ public class DAVConnection {
         for (Map.Entry<String, List<String>> entry : rawHeaders.entrySet()) {
             String headerName = entry.getKey();
             if (headerName.toUpperCase().startsWith("SVN")) {
-                List<String> value = entry.getValue();
-                String firstValue = (value != null && value.size() > 0) ? value.get(0) : null;
+                List<String> values = entry.getValue();
+                if (values == null) {
+                    continue;
+                }
+                String firstValue = (values != null && values.size() > 0) ? values.get(0) : null;
 
                 if (mySupportedPosts == null) {
                     mySupportedPosts = Collections.singletonList("create-txn");
@@ -786,7 +832,13 @@ public class DAVConnection {
                 } else if (DAVElement.SVN_ALLOW_BULK_UPDATES_HEADER.equals(headerName)) {
                     myServerAllowsBulk = firstValue;
                 } else if (DAVElement.SVN_SUPPORTED_POSTS_HEADER.equals(headerName)) {
-                    mySupportedPosts = new ArrayList<String>(value);
+                    mySupportedPosts = new ArrayList<String>();
+                    for (String value : values) {
+                        final String[] supportedPosts = value.split(",");
+                        for (String supportedPost : supportedPosts) {
+                            mySupportedPosts.add(supportedPost.trim());
+                        }
+                    }
                 } else if (DAVElement.SVN_REPOSITORY_MERGEINFO_HEADER.equals(headerName)) {
                     if (DAV_CAPABILITY_YES.equals(firstValue)) {
                         myCapabilities.put(SVNCapability.MERGE_INFO, DAV_CAPABILITY_YES);
