@@ -12,56 +12,31 @@
 
 package org.tmatesoft.svn.core.internal.io.dav;
 
-import java.io.File;
-import java.io.InputStream;
-import java.io.OutputStream;
-import java.util.ArrayList;
-import java.util.Collection;
-import java.util.Date;
-import java.util.HashMap;
-import java.util.HashSet;
-import java.util.Iterator;
-import java.util.LinkedList;
-import java.util.List;
-import java.util.Map;
-
-import org.tmatesoft.svn.core.ISVNDirEntryHandler;
-import org.tmatesoft.svn.core.ISVNLogEntryHandler;
-import org.tmatesoft.svn.core.SVNDepth;
-import org.tmatesoft.svn.core.SVNDirEntry;
-import org.tmatesoft.svn.core.SVNErrorCode;
-import org.tmatesoft.svn.core.SVNErrorMessage;
-import org.tmatesoft.svn.core.SVNException;
-import org.tmatesoft.svn.core.SVNLock;
-import org.tmatesoft.svn.core.SVNLogEntry;
-import org.tmatesoft.svn.core.SVNMergeInfo;
-import org.tmatesoft.svn.core.SVNMergeInfoInheritance;
-import org.tmatesoft.svn.core.SVNNodeKind;
-import org.tmatesoft.svn.core.SVNProperties;
-import org.tmatesoft.svn.core.SVNProperty;
-import org.tmatesoft.svn.core.SVNPropertyValue;
-import org.tmatesoft.svn.core.SVNRevisionProperty;
-import org.tmatesoft.svn.core.SVNURL;
+import org.tmatesoft.svn.core.*;
 import org.tmatesoft.svn.core.auth.ISVNAuthenticationManager;
 import org.tmatesoft.svn.core.internal.io.dav.handlers.*;
 import org.tmatesoft.svn.core.internal.io.dav.http.HTTPStatus;
 import org.tmatesoft.svn.core.internal.io.dav.http.IHTTPConnectionFactory;
 import org.tmatesoft.svn.core.internal.io.fs.FSErrors;
 import org.tmatesoft.svn.core.internal.io.fs.FSRepositoryUtil;
-import org.tmatesoft.svn.core.internal.util.SVNDate;
-import org.tmatesoft.svn.core.internal.util.SVNEncodingUtil;
-import org.tmatesoft.svn.core.internal.util.SVNHashMap;
-import org.tmatesoft.svn.core.internal.util.SVNHashSet;
-import org.tmatesoft.svn.core.internal.util.SVNPathUtil;
+import org.tmatesoft.svn.core.internal.util.*;
 import org.tmatesoft.svn.core.internal.wc.SVNDepthFilterEditor;
 import org.tmatesoft.svn.core.internal.wc.SVNErrorManager;
+import org.tmatesoft.svn.core.internal.wc.SVNEventFactory;
 import org.tmatesoft.svn.core.internal.wc.SVNFileUtil;
 import org.tmatesoft.svn.core.io.*;
-import org.tmatesoft.svn.core.wc.SVNRevision;
+import org.tmatesoft.svn.core.wc.ISVNEventHandler;
+import org.tmatesoft.svn.core.wc.SVNEvent;
+import org.tmatesoft.svn.core.wc.SVNEventAction;
 import org.tmatesoft.svn.core.wc2.SvnChecksum;
 import org.tmatesoft.svn.util.SVNLogType;
 import org.tmatesoft.svn.util.Version;
 
+import java.io.File;
+import java.io.InputStream;
+import java.io.OutputStream;
+import java.util.*;
+
 /**
  * @version 1.3
  * @author  TMate Software Ltd.
@@ -75,12 +50,17 @@ public class DAVRepository extends SVNRepository {
 
     private static boolean ourIsKeepCredentials = Boolean.valueOf(System.getProperty("svnkit.http.keepCredentials", Boolean.TRUE.toString())).booleanValue();
     private static boolean ourHttpV2Enabled = Boolean.valueOf(System.getProperty("svnkit.http.httpV2Enabled", Boolean.FALSE.toString())).booleanValue();
+    protected static boolean ourRedirectsEnabled = true; //e.g. http://... -> https://...
     private File mySpoolLocation;
 
     public static void setKeepCredentials(boolean keepCredentials) {
         ourIsKeepCredentials = keepCredentials;
     }
 
+    public static void setRedirectsEnabled(boolean ourRedirectsEnabled) {
+        DAVRepository.ourRedirectsEnabled = ourRedirectsEnabled;
+    }
+
     protected DAVRepository(IHTTPConnectionFactory connectionFactory, SVNURL location, ISVNSession options) {
         super(location, options);
         myConnectionFactory = connectionFactory;
@@ -224,20 +204,28 @@ public class DAVRepository extends SVNRepository {
     }
 
     public SVNNodeKind checkPath(String path, long revision) throws SVNException {
-        DAVBaselineInfo info = null;
-        SVNNodeKind kind = SVNNodeKind.NONE;
         try {
             openConnection();
             path = doGetFullPath(path);
             path = SVNEncodingUtil.uriEncode(path);
             DAVConnection connection = getConnection();
-            info = DAVUtil.getBaselineInfo(connection, this, path, revision, true, false, info);
-            kind = info.isDirectory ? SVNNodeKind.DIR : SVNNodeKind.FILE;
+            if (isValidRevision(revision)) {
+                final DAVBaselineInfo blInfo = DAVUtil.getStableURL(connection, this, path, revision, true, false, null);
+                path = SVNPathUtil.append(blInfo.baselineBase, blInfo.baselinePath);
+            }
+            final DAVProperties props = DAVUtil.getResourceProperties(connection, path,
+                    isValidRevision(revision) ? Long.toString(revision) : null , new DAVElement[] {DAVElement.RESOURCE_TYPE});
+
+            if (props != null && props.isCollection()) {
+                return SVNNodeKind.DIR;
+            } else {
+                return SVNNodeKind.FILE;
+            }
         } catch (SVNException e) {
             SVNErrorMessage error = e.getErrorMessage();
             while (error != null) {
                 if (error.getErrorCode() == SVNErrorCode.FS_NOT_FOUND) {
-                    return kind;
+                    return SVNNodeKind.NONE;
                 }
                 error = error.getChildErrorMessage();
             }
@@ -245,7 +233,6 @@ public class DAVRepository extends SVNRepository {
         } finally {
             closeConnection();
         }
-        return kind;
     }
 
     public SVNProperties getRevisionProperties(long revision, SVNProperties properties) throws SVNException {
@@ -702,8 +689,12 @@ public class DAVRepository extends SVNRepository {
                 SVNLock lock = null;
                 SVNErrorMessage error = null;
                 long revisionNumber = revision != null ? revision.longValue() : -1;
+                long timeout = -1;
+                if (handler instanceof ISVNLockTimeoutProvider) {
+                    timeout = ((ISVNLockTimeoutProvider) handler).getLockTimeout(repositoryPath, path, comment, force);
+                }
                 try {
-                     lock = connection.doLock(repositoryPath, path, this, comment, force, revisionNumber);
+                     lock = connection.doLock(repositoryPath, path, this, comment, force, revisionNumber, timeout);
                 } catch (SVNException e) {
                     error = null;
                     if (e.getErrorMessage() != null) {
@@ -1044,9 +1035,38 @@ public class DAVRepository extends SVNRepository {
         fireConnectionOpened();
         lock();
         if (myConnection == null) {
-            myConnection = createDAVConnection(myConnectionFactory, this);
-            myConnection.setReportResponseSpooled(isSpoolResponse());
-            myConnection.open(this);
+
+            final Set<SVNURL> attempted = new HashSet<SVNURL>();
+            final SVNURL[] correctedUrl = new SVNURL[1];
+            int attemptsLeft = 4;
+            while (attemptsLeft-- > 0) {
+                SVNURL originalLocation = myLocation;
+                correctedUrl[0] = null;
+                myConnection = createDAVConnection(myConnectionFactory, this);
+                myConnection.setReportResponseSpooled(isSpoolResponse());
+                myConnection.open(this, correctedUrl);
+
+                if (correctedUrl[0] == null) {
+                    break;
+                }
+                myOriginalLocations.add(originalLocation);
+
+                ISVNEventHandler eventHandler = getEventHandler();
+                if (eventHandler != null) {
+                    final SVNEvent event = SVNEventFactory.createSVNEvent(new File("."), SVNNodeKind.UNKNOWN, null, SVNRepository.INVALID_REVISION, SVNEventAction.URL_REDIRECT, SVNEventAction.URL_REDIRECT, null, null);
+                    event.setURL(correctedUrl[0]);
+                    eventHandler.handleEvent(event, -1);
+                }
+
+                if (attempted.contains(correctedUrl[0])) {
+                    final SVNErrorMessage errorMessage = SVNErrorMessage.create(SVNErrorCode.CLIENT_CYCLE_DETECTED, "Redirect cycle detected for URL ''{0}''", correctedUrl[0]);
+                    SVNErrorManager.error(errorMessage, SVNLogType.NETWORK);
+                }
+                attempted.add(correctedUrl[0]);
+
+                //setLocation() but avoid double locking
+                setLocationInternal(correctedUrl[0], false);
+            }
         }
     }
 
