@@ -11,28 +11,7 @@
  */
 package org.tmatesoft.svn.core.internal.io.fs;
 
-import java.io.File;
-import java.io.IOException;
-import java.io.OutputStream;
-import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.Collection;
-import java.util.Date;
-import java.util.HashMap;
-import java.util.HashSet;
-import java.util.Iterator;
-import java.util.Map;
-import java.util.Set;
-
-import org.tmatesoft.svn.core.SVNErrorCode;
-import org.tmatesoft.svn.core.SVNErrorMessage;
-import org.tmatesoft.svn.core.SVNException;
-import org.tmatesoft.svn.core.SVNLock;
-import org.tmatesoft.svn.core.SVNNodeKind;
-import org.tmatesoft.svn.core.SVNProperties;
-import org.tmatesoft.svn.core.SVNProperty;
-import org.tmatesoft.svn.core.SVNPropertyValue;
-import org.tmatesoft.svn.core.SVNRevisionProperty;
+import org.tmatesoft.svn.core.*;
 import org.tmatesoft.svn.core.internal.util.SVNDate;
 import org.tmatesoft.svn.core.internal.util.SVNHashSet;
 import org.tmatesoft.svn.core.internal.util.SVNPathUtil;
@@ -43,6 +22,11 @@ import org.tmatesoft.svn.core.io.SVNRepository;
 import org.tmatesoft.svn.util.SVNDebugLog;
 import org.tmatesoft.svn.util.SVNLogType;
 
+import java.io.File;
+import java.io.IOException;
+import java.io.OutputStream;
+import java.util.*;
+
 
 /**
  * @version 1.3
@@ -119,10 +103,6 @@ public class FSCommitter {
         makePathMutable(parentPath, path);
         SVNProperties properties = parentPath.getRevNode().getProperties(myFSFS);
 
-        if (properties.isEmpty() && propValue == null) {
-            return;
-        }
-
         boolean mergeInfoModified = false;
         if (myFSFS.supportsMergeInfo() && name.equals(SVNProperty.MERGE_INFO)) {
             long increment = 0;
@@ -216,7 +196,7 @@ public class FSCommitter {
     }
 
     public void makeDir(String path) throws SVNException {
-        SVNPathUtil.checkPathIsValid(path);
+        checkFSPathIsValid(path);
         FSTransactionRoot txnRoot = getTxnRoot();
         String txnId = txnRoot.getTxnID();
         FSParentPath parentPath = txnRoot.openPath(path, false, true);
@@ -343,7 +323,7 @@ public class FSCommitter {
                         });
                     } catch (SVNException e) {
                         // ignore
-                        SVNDebugLog.getDefaultLog().logError(SVNLogType.FSFS, e);
+                        SVNDebugLog.getDefaultLog().logFiner(SVNLogType.FSFS, e);
                     }
                 }
             }
@@ -825,4 +805,51 @@ public class FSCommitter {
         }
     }
 
+    private static void checkFSPathIsValid(String path) throws SVNException {
+        SVNPathUtil.checkPathIsValid(path);
+
+        if (containsBackPath(path) || containsDotPath(path)) {
+            SVNErrorMessage err = SVNErrorMessage.create(SVNErrorCode.FS_PATH_SYNTAX,
+                    "Path ''{0}'' contains '.' or '..' element", path);
+            SVNErrorManager.error(err, SVNLogType.DEFAULT);
+        }
+
+        if (path.contains("\n")) {
+            SVNErrorMessage err = SVNErrorMessage.create(SVNErrorCode.FS_PATH_SYNTAX,
+                    "Invalid control character '0x0a' in path ''{0}''", path);
+            SVNErrorManager.error(err, SVNLogType.DEFAULT);
+        }
+    }
+
+    private static boolean containsBackPath(String path) {
+        if (path.length() == 0 || path.length() == 1) {
+            return false;
+        }
+        if (path.charAt(0) == '.' && path.charAt(1) == '.' && (path.length() == 2 || path.charAt(2) == '/')) {
+            return true;
+        }
+        if (path.length() == 2) {
+            return false;
+        }
+        if (path.contains("/../")) {
+            return true;
+        }
+        return path.endsWith("/..");
+    }
+
+    private static boolean containsDotPath(String path) {
+        if (path.length() == 0) {
+            return false;
+        }
+        if (path.charAt(0) == '.' && (path.length() == 1 || path.charAt(1) == '/')) {
+            return true;
+        }
+        if (path.length() == 1) {
+            return false;
+        }
+        if (path.contains("/./")) {
+            return true;
+        }
+        return path.endsWith("/.");
+    }
 }
