@@ -27,6 +27,7 @@ import org.tmatesoft.svn.core.SVNErrorMessage;
 import org.tmatesoft.svn.core.SVNException;
 import org.tmatesoft.svn.core.SVNNodeKind;
 import org.tmatesoft.svn.core.internal.delta.SVNDeltaCombiner;
+import org.tmatesoft.svn.core.internal.delta.SVNDeltaCompression;
 import org.tmatesoft.svn.core.internal.io.fs.index.FSLogicalAddressingIndex;
 import org.tmatesoft.svn.core.internal.io.fs.index.FSP2LEntry;
 import org.tmatesoft.svn.core.internal.io.fs.index.FSP2LProtoIndex;
@@ -64,11 +65,11 @@ public class FSOutputStream extends OutputStream implements ISVNDeltaConsumer {
     private long mySourceOffset;
     private ByteArrayOutputStream myTextBuffer;
     private boolean myIsClosed;
-    private boolean myIsCompress;
+    private SVNDeltaCompression myDeltaCompression;
     private FSWriteLock myTxnLock;
 
-    private FSOutputStream(FSRevisionNode revNode, CountingOutputStream targetFileOS, File targetFile, InputStream source, long deltaStart, 
-            long repSize, long repOffset, FSTransactionRoot txnRoot, boolean compress, FSWriteLock txnLock) throws SVNException {
+    private FSOutputStream(FSRevisionNode revNode, CountingOutputStream targetFileOS, File targetFile, InputStream source, long deltaStart,
+            long repSize, long repOffset, FSTransactionRoot txnRoot, SVNDeltaCompression compression, FSWriteLock txnLock) throws SVNException {
         myTxnRoot = txnRoot;
         myTargetFileOS = targetFileOS;
         myTargetFile = targetFile;
@@ -97,10 +98,10 @@ public class FSOutputStream extends OutputStream implements ISVNDeltaConsumer {
             SVNErrorManager.error(err, nsae, SVNLogType.FSFS);
         }
 
-        myIsCompress = compress;
+        myDeltaCompression = compression;
     }
 
-    private void reset(FSRevisionNode revNode, CountingOutputStream targetFileOS, File targetFile, InputStream source, long deltaStart, 
+    private void reset(FSRevisionNode revNode, CountingOutputStream targetFileOS, File targetFile, InputStream source, long deltaStart,
             long repSize, long repOffset, FSTransactionRoot txnRoot, FSWriteLock txnLock) {
         myTxnRoot = txnRoot;
         myTargetFileOS = targetFileOS;
@@ -119,7 +120,18 @@ public class FSOutputStream extends OutputStream implements ISVNDeltaConsumer {
         myTxnLock = txnLock;
     }
 
+    /**
+     * @deprecated use {@link #createStream(FSRevisionNode, FSTransactionRoot, OutputStream, SVNDeltaCompression)} instead
+     */
+    @Deprecated
     public static OutputStream createStream(FSRevisionNode revNode, FSTransactionRoot txnRoot, OutputStream dstStream, boolean compress) throws SVNException {
+        return createStream(revNode, txnRoot, dstStream, SVNDeltaCompression.fromLegacyCompress(compress));
+    }
+
+    /**
+     * @since 1.10
+     */
+    public static OutputStream createStream(FSRevisionNode revNode, FSTransactionRoot txnRoot, OutputStream dstStream, SVNDeltaCompression compression) throws SVNException {
         if (revNode.getType() != SVNNodeKind.FILE) {
             SVNErrorMessage err = SVNErrorMessage.create(SVNErrorCode.FS_NOT_FILE, "Attempted to set textual contents of a *non*-file node");
             SVNErrorManager.error(err, SVNLogType.FSFS);
@@ -138,7 +150,7 @@ public class FSOutputStream extends OutputStream implements ISVNDeltaConsumer {
         try {
             txnLock = FSWriteLock.getWriteLockForTxn(txnRoot.getTxnID(), txnRoot.getOwner());
             txnLock.lock();
-            
+
             File targetFile = txnRoot.getWritableTransactionProtoRevFile();
             offset = targetFile.length();
             targetOS = SVNFileUtil.openFileForWriting(targetFile, true);
@@ -163,8 +175,8 @@ public class FSOutputStream extends OutputStream implements ISVNDeltaConsumer {
                 return dstStream;
             }
 
-            return new FSOutputStream(revNode, revWriter, targetFile, sourceStream, deltaStart, 0, offset, txnRoot, 
-                    compress, txnLock);
+            return new FSOutputStream(revNode, revWriter, targetFile, sourceStream, deltaStart, 0, offset, txnRoot,
+                    compression, txnLock);
 
         } catch (IOException ioe) {
             SVNFileUtil.closeFile(targetOS);
@@ -242,7 +254,7 @@ public class FSOutputStream extends OutputStream implements ISVNDeltaConsumer {
 
             rep.setMD5HexDigest(SVNFileUtil.toHexDigest(myMD5Digest));
             rep.setSHA1HexDigest(SVNFileUtil.toHexDigest(mySHA1Digest));
-            
+
             FSFS fsfs = myTxnRoot.getOwner();
             FSRepresentation oldRep = getSharedRepresentation(fsfs, rep, null);
 
@@ -299,7 +311,7 @@ public class FSOutputStream extends OutputStream implements ISVNDeltaConsumer {
     public OutputStream textDeltaChunk(String path, SVNDiffWindow diffWindow) throws SVNException {
         mySourceOffset += diffWindow.getSourceViewLength();
         try {
-            diffWindow.writeTo(myTargetFileOS, !isHeaderWritten, myIsCompress);
+            diffWindow.writeTo(myTargetFileOS, !isHeaderWritten, myDeltaCompression);
             isHeaderWritten = true;
         } catch (IOException ioe) {
             SVNErrorMessage err = SVNErrorMessage.create(SVNErrorCode.IO_ERROR, ioe.getLocalizedMessage());
@@ -340,9 +352,8 @@ public class FSOutputStream extends OutputStream implements ISVNDeltaConsumer {
                     if (e.getErrorMessage().getErrorCode() == SVNErrorCode.FS_CORRUPT || e.getErrorMessage().getErrorCode().getCategory() == SVNErrorCode.MALFUNC_CATEGORY) {
                         throw e;
                     }
-
                     // explicitly ignore.
-                    SVNDebugLog.getDefaultLog().logError(SVNLogType.FSFS, e);
+                    SVNDebugLog.getDefaultLog().logFiner(SVNLogType.FSFS, e);
                 }
                 if (oldRepresentation != null) {
                     checkRepresentation(myTxnRoot.getOwner(), oldRepresentation, null);
@@ -390,7 +401,7 @@ public class FSOutputStream extends OutputStream implements ISVNDeltaConsumer {
             if (entry == null ||
                     entry.getType().getCode() < FSP2LProtoIndex.ItemType.FILE_REP.getCode() ||
                     entry.getType().getCode() > FSP2LProtoIndex.ItemType.DIR_PROPS.getCode()) {
-                SVNErrorMessage errorMessage = SVNErrorMessage.create(SVNErrorCode.FS_CORRUPT, "No representation found at offset {0} for item %s in revision {1}", new Object[]{new Long(offset), new Long(representation.getItemIndex())});
+                SVNErrorMessage errorMessage = SVNErrorMessage.create(SVNErrorCode.FS_CORRUPT, "No representation found at offset {0} for item %s in revision {1}", new Object[]{offset, representation.getItemIndex()});
                 SVNErrorManager.error(errorMessage, SVNLogType.FSFS);
             }
         } else {
