@@ -54,8 +54,6 @@ public class FSRepositoryUtil {
     
     public static final int MAX_KEY_SIZE = 200;
     private static final int BYTES_IN_LONG = Long.SIZE / 8;
-    private static final byte[] BUFFER = new byte[BYTES_IN_LONG];
-
 
     private static final ThreadLocal<byte[]> ourCopyBuffer = new ThreadLocal<byte[]>() {
         @Override
@@ -385,7 +383,7 @@ public class FSRepositoryUtil {
         if (nextKeyLength >= MAX_KEY_SIZE) {
             SVNErrorMessage err = SVNErrorMessage.create(SVNErrorCode.UNKNOWN, 
                     "FATAL error: new key length is greater than the threshold {0}", 
-                    new Integer(MAX_KEY_SIZE));
+                    new Object[]{MAX_KEY_SIZE});
             SVNErrorManager.error(err, SVNLogType.FSFS);
         }
         if (carry) {
@@ -402,14 +400,14 @@ public class FSRepositoryUtil {
                     "unreleased dev builds; see " +
                     "http://subversion.apache.org" +
                     "/docs/release-notes/1.7#revprop-packing",  
-                    new Integer(FSFS.MIN_PACKED_REVPROP_SQLITE_DEV_FORMAT));
+                    new Object[]{FSFS.MIN_PACKED_REVPROP_SQLITE_DEV_FORMAT});
             SVNErrorManager.error(err, SVNLogType.FSFS);
         }
         if (format < FSFS.DB_FORMAT_LOW || format > FSFS.DB_FORMAT) {
             SVNErrorMessage err = SVNErrorMessage.create(SVNErrorCode.FS_UNSUPPORTED_FORMAT, 
                     "Expected FS format between ''{0}'' and ''{1}''; found format ''{2}''", 
-                    new Object[] {new Integer(FSFS.DB_FORMAT_LOW), new Integer(FSFS.DB_FORMAT), 
-                    new Integer(format)});
+                    new Object[] {FSFS.DB_FORMAT_LOW, FSFS.DB_FORMAT,
+                            format});
             SVNErrorManager.error(err, SVNLogType.FSFS);
         }
     }
@@ -438,23 +436,25 @@ public class FSRepositoryUtil {
     }
 
     public static long readLongLittleEndian(RandomAccessFile randomAccessFile) throws IOException {
-        final int bytesRead = randomAccessFile.read(BUFFER, 0, BYTES_IN_LONG);
+        final byte[] buffer = new byte[BYTES_IN_LONG];
+        final int bytesRead = randomAccessFile.read(buffer, 0, BYTES_IN_LONG);
         if (bytesRead < 0) {
             return bytesRead;
         }
         long value = 0;
         for (int i = BYTES_IN_LONG - 1; i >= 0; i--) {
-            value = (value << 8) + (BUFFER[i] & 0xffL);
+            value = (value << 8) + (buffer[i] & 0xffL);
         }
         return value;
     }
 
     public static void writeLongLittleEndian(RandomAccessFile randomAccessFile, long value) throws IOException {
+        final byte[] buffer = new byte[BYTES_IN_LONG];
         for (int i = 0; i < BYTES_IN_LONG; i++) {
-            BUFFER[i] = (byte) value;
+            buffer[i] = (byte) value;
             value >>= 8;
         }
-        randomAccessFile.write(BUFFER, 0, BYTES_IN_LONG);
+        randomAccessFile.write(buffer, 0, BYTES_IN_LONG);
     }
 
     public static int encodeInt(byte[] bytes, long value) {
