@@ -28,7 +28,7 @@ public class FSEmptyRepresentationCacheManagerFactory implements IFSRepresentati
      * @param path
      * @throws SVNException
      */
-    public void createRepresentationCache(File path) throws SVNException {
+    public void createRepresentationCache(int format, File path) throws SVNException {
     }
 
     /**
