@@ -40,12 +40,11 @@ import org.tmatesoft.svn.util.SVNLogType;
 public class FSRepresentationCacheManager implements IFSRepresentationCacheManager {
     
     public static final String REP_CACHE_TABLE = "rep_cache";
-    private static final int REP_CACHE_DB_FORMAT =  1;
     private static final String REP_CACHE_DB_SQL =  "create table rep_cache (hash text not null primary key, " +
                                                     "                        revision integer not null, " + 
                                                     "                        offset integer not null, " + 
                                                     "                        size integer not null, " +
-                                                    "                        expanded_size integer not null); ";
+                                                    "                        expanded_size integer not null) without rowid;";
 
     private SqlJetDb myRepCacheDB;
     private ISqlJetTable myTable;
@@ -57,7 +56,7 @@ public class FSRepresentationCacheManager implements IFSRepresentationCacheManag
             cacheObj.myRepCacheDB = SqlJetDb.open(fsfs.getRepositoryCacheFile(), true);
             cacheObj.myRepCacheDB.setSafetyLevel(SqlJetSafetyLevel.OFF);
             
-            checkFormat(cacheObj.myRepCacheDB);
+            checkFormat(fsfs.getDBFormat(), cacheObj.myRepCacheDB);
             cacheObj.myTable = cacheObj.myRepCacheDB.getTable(REP_CACHE_TABLE);
         } catch (SqlJetException e) {
             SVNDebugLog.getDefaultLog().logError(SVNLogType.FSFS, e);
@@ -67,11 +66,11 @@ public class FSRepresentationCacheManager implements IFSRepresentationCacheManag
         return cacheObj;
     }
     
-    public static void createRepresentationCache(File path) throws SVNException {
+    public static void createRepresentationCache(int format, File path) throws SVNException {
         SqlJetDb db = null;
         try {
             db = SqlJetDb.open(path, true);
-            checkFormat(db);
+            checkFormat(format, db);
         } catch (SqlJetException e) {
             SVNDebugLog.getDefaultLog().logError(SVNLogType.FSFS, e);
         } finally {
@@ -85,20 +84,21 @@ public class FSRepresentationCacheManager implements IFSRepresentationCacheManag
         }
     }
 
-    private static void checkFormat(final SqlJetDb db) throws SqlJetException {
+    private static void checkFormat(final int fsFormat, final SqlJetDb db) throws SqlJetException {
+        final int schemaVersion = FSFS.getRepCacheSchemaFormat(fsFormat);
         db.runWithLock(new ISqlJetRunnableWithLock() {
             public Object runWithLock(SqlJetDb db) throws SqlJetException {
                 int version = db.getOptions().getUserVersion();
-                if (version < REP_CACHE_DB_FORMAT) {
+                if (version < schemaVersion) {
                     db.getOptions().setAutovacuum(true);
                     db.runWriteTransaction(new ISqlJetTransaction() {
                         public Object run(SqlJetDb db) throws SqlJetException {
-                            db.getOptions().setUserVersion(REP_CACHE_DB_FORMAT);
+                            db.getOptions().setUserVersion(schemaVersion);
                             db.createTable(FSRepresentationCacheManager.REP_CACHE_DB_SQL);
                             return null;
                         }
                     });
-                } else if (version > REP_CACHE_DB_FORMAT) {
+                } else if (version > schemaVersion) {
                     throw new SqlJetException("Schema format " + version + " not recognized");   
                 }
                 return null;
@@ -128,9 +128,9 @@ public class FSRepresentationCacheManager implements IFSRepresentationCacheManag
         }
         
         try {
-            myTable.insert(new Object[] { representation.getSHA1HexDigest(), new Long(representation.getRevision()),
-                    new Long(representation.getItemIndex()), new Long(representation.getSize()),
-                    new Long(representation.getExpandedSize()) });
+            myTable.insert(new Object[] { representation.getSHA1HexDigest(), representation.getRevision(),
+                    representation.getItemIndex(), representation.getSize(),
+                    representation.getExpandedSize()});
         } catch (SqlJetException e) {
             SVNErrorManager.error(convertError(e), SVNLogType.FSFS);
         }
