@@ -174,7 +174,7 @@ class SVNCommitEditor implements ISVNEditor {
         String fileToken = (String) myFilesToTokens.get(path);
 
         try {
-            diffWindow.writeTo(myConnection.getDeltaStream(fileToken), myDiffWindowCount == 0, myConnection.isSVNDiff1());
+            diffWindow.writeTo(myConnection.getDeltaStream(fileToken), myDiffWindowCount == 0, myConnection.getDeltaCompression());
             myDiffWindowCount++;
             return SVNFileUtil.DUMMY_OUT;
         } catch (IOException e) {
@@ -248,7 +248,7 @@ class SVNCommitEditor implements ISVNEditor {
     }
 
     private static Long getRevisionObject(long rev) {
-        return rev >= 0 ? new Long(rev) : null;
+        return rev >= 0 ? rev : null;
     }
 
     private final static class DirBaton {
