@@ -17,6 +17,7 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
 import java.io.SequenceInputStream;
+import java.net.SocketTimeoutException;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Set;
@@ -29,6 +30,7 @@ import org.tmatesoft.svn.core.auth.BasicAuthenticationManager;
 import org.tmatesoft.svn.core.auth.ISVNAuthenticationManager;
 import org.tmatesoft.svn.core.auth.ISVNAuthenticationManagerExt;
 import org.tmatesoft.svn.core.auth.SVNAuthentication;
+import org.tmatesoft.svn.core.internal.delta.SVNDeltaCompression;
 import org.tmatesoft.svn.core.internal.util.SVNHashSet;
 import org.tmatesoft.svn.core.internal.wc.SVNClassLoader;
 import org.tmatesoft.svn.core.internal.wc.SVNErrorManager;
@@ -46,7 +48,7 @@ public class SVNConnection {
     private OutputStream myOutputStream;
     private InputStream myInputStream;
     private SVNRepositoryImpl myRepository;
-    private boolean myIsSVNDiff1;
+    private SVNDeltaCompression myDeltaCompression = SVNDeltaCompression.None;
     private boolean myIsCommitRevprops;
     private boolean myIsReopening = false;
     private boolean myIsCredentialsReceived = false;
@@ -58,6 +60,7 @@ public class SVNConnection {
     
     private static final String EDIT_PIPELINE = "edit-pipeline";
     private static final String SVNDIFF1 = "svndiff1";
+    private static final String ACCEPTS_SVNDIFF2 = "accepts-svndiff2";
     private static final String ABSENT_ENTRIES = "absent-entries";
     private static final String COMMIT_REVPROPS = "commit-revprops";
     private static final String MERGE_INFO = "mergeinfo";
@@ -89,9 +92,20 @@ public class SVNConnection {
     public String getRealm() {
         return myRealm;
     }
-    
+
+    /**
+     * @deprecated use {@link #getDeltaCompression()} instead
+     */
+    @Deprecated
     public boolean isSVNDiff1() {
-        return myIsSVNDiff1;
+        return myDeltaCompression == SVNDeltaCompression.Zlib;
+    }
+
+    /**
+     * @since 1.10
+     */
+    public SVNDeltaCompression getDeltaCompression() {
+        return myDeltaCompression;
     }
 
     public boolean isCommitRevprops() {
@@ -103,6 +117,9 @@ public class SVNConnection {
         int r = 0;
         try {
             r = getInputStream().read(bytes);
+        } catch (SocketTimeoutException e) {
+            SVNErrorMessage err = SVNErrorMessage.create(SVNErrorCode.RA_SVN_IO_ERROR, "time out reading data", null, SVNErrorMessage.TYPE_ERROR, e);
+            SVNErrorManager.error(err, e, SVNLogType.NETWORK);
         } catch (IOException e) {
             SVNErrorMessage err = SVNErrorMessage.create(SVNErrorCode.RA_SVN_MALFORMED_DATA, "Handshake failed: ''{0}''", e.getMessage());
             SVNErrorManager.error(err, SVNLogType.NETWORK);
@@ -151,12 +168,16 @@ public class SVNConnection {
             SVNErrorManager.error(SVNErrorMessage.create(SVNErrorCode.RA_SVN_BAD_VERSION, 
             		"Server does not support edit pipelining"), SVNLogType.NETWORK);
         }
-        
-        
-        myIsSVNDiff1 = SVNReader.hasValue(items, 3, SVNDIFF1);
+
+        if (SVNReader.hasValue(items, 3, ACCEPTS_SVNDIFF2)) {
+            myDeltaCompression = SVNDeltaCompression.LZ4;
+        } else if (SVNReader.hasValue(items, 3, SVNDIFF1)) {
+            myDeltaCompression = SVNDeltaCompression.Zlib;
+        }
+
         myIsCommitRevprops = SVNReader.hasValue(items, 3, COMMIT_REVPROPS);
 
-        write("(n(wwwwww)s)", new Object[]{"2", EDIT_PIPELINE, SVNDIFF1, ABSENT_ENTRIES, DEPTH, MERGE_INFO, LOG_REVPROPS, 
+        write("(n(wwwwwww)s)", new Object[]{"2", EDIT_PIPELINE, SVNDIFF1, ACCEPTS_SVNDIFF2, ABSENT_ENTRIES, DEPTH, MERGE_INFO, LOG_REVPROPS,
                 repository.getLocation().toString()});
     }
 
@@ -323,7 +344,7 @@ public class SVNConnection {
         write("(w(", buffer);
         for (; error != null; error = error.getChildErrorMessage()) {
             String message = error.getMessage() == null ? "" : error.getMessage();
-            buffer = new Object[]{new Long(error.getErrorCode().getCode()), message, "", new Integer(0)};
+            buffer = new Object[]{(long) error.getErrorCode().getCode(), message, "", 0};
             write("(nssn)", buffer);
         }
         write(")", null);
@@ -402,7 +423,7 @@ public class SVNConnection {
         if (myInputStream == null) {
             try {
                 InputStream is = myConnector.getInputStream();
-                myInputStream = myRepository.getDebugLog().createLogStream(SVNLogType.NETWORK, is); 
+                myInputStream = myRepository.getDebugLog().createLogStream(SVNLogType.NETWORK, is);
                 myLoggingInputStream = myInputStream;
             } catch (IOException e) {
                 SVNErrorManager.error(SVNErrorMessage.create(SVNErrorCode.RA_SVN_IO_ERROR, e.getMessage()), e, SVNLogType.NETWORK);
