@@ -13,6 +13,7 @@ package org.tmatesoft.svn.core.internal.io.svn;
 
 import java.io.IOException;
 import java.io.InputStream;
+import java.net.SocketTimeoutException;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
@@ -85,7 +86,7 @@ public class SVNReader {
                     } else if (svnItem.getKind() == SVNItem.WORD) {
                         list.set(i, svnItem.getWord());
                     } else if (svnItem.getKind() == SVNItem.NUMBER) {
-                        list.set(i, new Long(svnItem.getNumber()));
+                        list.set(i, svnItem.getNumber());
                     }
                 }
             }
@@ -317,7 +318,7 @@ public class SVNReader {
             }
 
             if ((ch == 'n' || ch == 'r') && item.getKind() == SVNItem.NUMBER) {
-                values.add(new Long(item.getNumber()));
+                values.add(item.getNumber());
             } else if (ch == 's' && item.getKind() == SVNItem.BYTES) {
                 try {
                     values.add(new String(item.getBytes(), UTF8_CHARSET_STRING));
@@ -350,7 +351,7 @@ public class SVNReader {
                         break;
                     case'r':
                     case'n':
-                        values.add(new Long(SVNRepository.INVALID_REVISION));
+                        values.add(SVNRepository.INVALID_REVISION);
                         break;
                     case's':
                     case'w':
@@ -416,6 +417,10 @@ public class SVNReader {
                         }
                         toRead -= r;
                     }
+                } catch (SocketTimeoutException e) {
+                    SVNDebugLog.getDefaultLog().logFinest(SVNLogType.NETWORK, e);
+                    SVNErrorMessage err = SVNErrorMessage.create(SVNErrorCode.RA_SVN_IO_ERROR, "time out reading data", null, SVNErrorMessage.TYPE_ERROR, e);
+                    SVNErrorManager.error(err, e, SVNLogType.NETWORK);
                 } catch (IOException e) {
                     SVNDebugLog.getDefaultLog().logFinest(SVNLogType.NETWORK, e);
                     SVNErrorMessage err = SVNErrorMessage.create(SVNErrorCode.RA_SVN_MALFORMED_DATA);
@@ -472,6 +477,10 @@ public class SVNReader {
                 SVNErrorMessage err = SVNErrorMessage.create(SVNErrorCode.RA_SVN_MALFORMED_DATA);
                 SVNErrorManager.error(err, SVNLogType.NETWORK);
             }
+        } catch (SocketTimeoutException e) {
+            SVNDebugLog.getDefaultLog().logFinest(SVNLogType.NETWORK, e);
+            SVNErrorMessage err = SVNErrorMessage.create(SVNErrorCode.RA_SVN_IO_ERROR, "time out reading data", null, SVNErrorMessage.TYPE_ERROR, e);
+            SVNErrorManager.error(err, e, SVNLogType.NETWORK);
         } catch (IOException e) {
             SVNDebugLog.getDefaultLog().logFinest(SVNLogType.NETWORK, e);
             SVNErrorMessage err = SVNErrorMessage.create(SVNErrorCode.RA_SVN_MALFORMED_DATA);
