@@ -11,6 +11,8 @@
  */
 package org.tmatesoft.svn.core.internal.util.jna;
 
+import java.io.File;
+
 import org.tmatesoft.svn.core.SVNException;
 import org.tmatesoft.svn.core.internal.wc.ISVNGnomeKeyringPasswordProvider;
 import org.tmatesoft.svn.core.internal.wc.SVNFileType;
@@ -18,8 +20,6 @@ import org.tmatesoft.svn.core.internal.wc.SVNFileUtil;
 import org.tmatesoft.svn.util.SVNDebugLog;
 import org.tmatesoft.svn.util.SVNLogType;
 
-import java.io.File;
-
 
 /**
  * @version 1.3
@@ -112,6 +112,13 @@ public class SVNJNAUtil {
         return null;
     }
 
+    public static Long getLastModifiedMicros(File file) {
+        if (isJNAPresent()) {
+            return SVNLinuxUtil.getLastModifiedMicros(file);
+        }
+        return null;
+    }
+
     // linux and win32.
     public static boolean setWritable(File file) {
         if (isJNAPresent()) {
@@ -136,6 +143,20 @@ public class SVNJNAUtil {
         }
         return false;
     }
+
+    public static int flock(File file, boolean exclusive) {
+        if (isJNAPresent()) {
+            return SVNLinuxUtil.flock(file, exclusive);
+        }
+        return -1;
+    }
+
+    public static boolean unflock(int fd) {
+        if (isJNAPresent()) {
+            return SVNLinuxUtil.unflock(fd);
+        }
+        return false;
+    }
     
     public static char[] decrypt(char[] encryptedData) {
         if (isJNAPresent()) {
