@@ -5,10 +5,12 @@ import java.io.File;
 public class SVNPatchTargetInfo {
 
     private final File localAbsPath;
+    private final boolean added;
     private final boolean deleted;
 
-    public SVNPatchTargetInfo(File localAbsPath, boolean deleted) {
+    public SVNPatchTargetInfo(File localAbsPath, boolean added, boolean deleted) {
         this.localAbsPath = localAbsPath;
+        this.added = added;
         this.deleted = deleted;
     }
 
@@ -16,6 +18,10 @@ public class SVNPatchTargetInfo {
         return localAbsPath;
     }
 
+    public boolean isAdded() {
+        return added;
+    }
+
     public boolean isDeleted() {
         return deleted;
     }
