@@ -32,6 +32,11 @@ public class SVNWCDbDeleteLockRecursively extends SVNSqlJetDeleteStatement {
         return getColumnString(SVNWCDbSchema.LOCK__Fields.repos_relpath);
     }
 
+    @Override
+    protected Enum<?> getRowPathField() throws SVNException {
+        return SVNWCDbSchema.LOCK__Fields.repos_relpath;
+    }
+
     @Override
     protected Object[] getWhere() throws SVNException {
         return new Object[] {getBind(1)};
