@@ -213,6 +213,9 @@ public enum SVNWCDbStatements {
     INSERT_WORKING_NODE_COPY_FROM(SVNWCDbInsertWorkingNodeCopyFrom.class),
     SELECT_MOVED_FROM_FOR_DELETE(SVNWCDbSelectMovedFromForDelete.class),
     CLEAR_MOVED_TO_FROM_DEST(SVNWCDbClearMovedToFromDest.class),
+    SELECT_MOVED_DESCENDANTS_SRC(SVNWCDbSelectMovedDescendantsSrc.class),
+    FIND_CONFLICT_DESCENDANT(SVNWCDbFindConflictDescendant.class),
+    SELECT_MOVED_TO_NODE(SVNWCDbSelectMovedToNode.class),
     //1.7 versions of the requests
     SELECT_ACTUAL_CHILDREN_CONFLICT_17(SVNWCDbSelectActualChildrenConflict17.class),
     SELECT_ACTUAL_CHILDREN_INFO_17(SVNWCDbSelectActualChildrenInfo17.class),
@@ -221,6 +224,7 @@ public enum SVNWCDbStatements {
     UPDATE_ACTUAL_CONFLICT_DATA_17(SVNWCDbUpdateActualConflictData17.class),
     INSERT_ACTUAL_CONFLICT_DATA_17(SVNWCDbInsertActualConflictData17.class),
     SELECT_MOVED_FROM_RELPATH_17(SVNWCDbSelectMovedFromRelPath17.class),
+    SELECT_MOVED_HERE_CHILDREN17(SVNWCDbSelectMovedHereChildren17.class),
     INSERT_ACTUAL_NODE_17(SVNWCDbInsertActualNode17.class)
     ;
     
