@@ -1,10 +1,39 @@
 package org.tmatesoft.svn.core.internal.wc2.ng;
 
+import java.io.BufferedInputStream;
+import java.io.ByteArrayInputStream;
+import java.io.ByteArrayOutputStream;
+import java.io.File;
+import java.io.FileInputStream;
+import java.io.IOException;
+import java.io.InputStream;
+import java.io.OutputStream;
+import java.io.OutputStreamWriter;
+import java.io.RandomAccessFile;
+import java.io.UnsupportedEncodingException;
+import java.io.Writer;
+import java.util.ArrayList;
+import java.util.Collection;
+import java.util.HashSet;
+import java.util.Iterator;
+import java.util.List;
+import java.util.Map;
+import java.util.Set;
+import java.util.TreeMap;
+import java.util.zip.DeflaterOutputStream;
+
 import de.regnis.q.sequence.line.diff.QDiffGenerator;
 import de.regnis.q.sequence.line.diff.QDiffGeneratorFactory;
 import de.regnis.q.sequence.line.diff.QDiffManager;
 import de.regnis.q.sequence.line.diff.QDiffUniGenerator;
-import org.tmatesoft.svn.core.*;
+import org.tmatesoft.svn.core.ISVNCanceller;
+import org.tmatesoft.svn.core.SVNErrorCode;
+import org.tmatesoft.svn.core.SVNErrorMessage;
+import org.tmatesoft.svn.core.SVNException;
+import org.tmatesoft.svn.core.SVNMergeRangeList;
+import org.tmatesoft.svn.core.SVNProperties;
+import org.tmatesoft.svn.core.SVNProperty;
+import org.tmatesoft.svn.core.SVNPropertyValue;
 import org.tmatesoft.svn.core.internal.util.SVNHashMap;
 import org.tmatesoft.svn.core.internal.util.SVNMergeInfoUtil;
 import org.tmatesoft.svn.core.internal.util.SVNPathUtil;
@@ -17,11 +46,16 @@ import org.tmatesoft.svn.core.wc.SVNDiffOptions;
 import org.tmatesoft.svn.core.wc2.SvnTarget;
 import org.tmatesoft.svn.util.SVNLogType;
 
-import java.io.*;
-import java.util.*;
-
 public class SvnDiffGenerator implements ISvnDiffGenerator {
 
+    private static final String B85_LENGTHS_TABLE = "ABCDEFGHIJKLMNOPQRSTUVWXYZ" +
+                    "abcdefghijklmnopqrstuvwxyz";
+    public static final String B85_TABLE = "0123456789" +
+            "ABCDEFGHIJKLMNOPQRSTUVWXYZ" +
+            "abcdefghijklmnopqrstuvwxyz" +
+            "!#$%&()*+-;<=>?@^_`{|}~";
+
+
     protected static final String WC_REVISION_LABEL = "(working copy)";
     protected static final String PROPERTIES_SEPARATOR = "___________________________________________________________________";
     protected static final String HEADER_SEPARATOR = "===================================================================";
@@ -49,6 +83,7 @@ public class SvnDiffGenerator implements ISvnDiffGenerator {
     private ISVNOptions options;
     private boolean propertiesOnly;
     private boolean ignoreProperties;
+    private ISVNCanceller canceller;
 
     private String getDisplayPath(SvnTarget target) {
         String relativePath;
@@ -218,6 +253,9 @@ public class SvnDiffGenerator implements ISvnDiffGenerator {
         if (isIgnoreProperties()) {
             return;
         }
+        if (dirWasAdded && !isDiffAdded()) {
+            return;
+        }
         ensureEncodingAndEOLSet();
         String displayPath = getDisplayPath(target);
 
@@ -228,50 +266,48 @@ public class SvnDiffGenerator implements ISvnDiffGenerator {
             displayPath = ".";
         }
 
+        if (useGitFormat) {
+            targetString1 = adjustRelativeToReposRoot(targetString1);
+            targetString2 = adjustRelativeToReposRoot(targetString2);
+        }
+
+        String newTargetString = displayPath;
+        String newTargetString1 = targetString1;
+        String newTargetString2 = targetString2;
+
+        String commonAncestor = SVNPathUtil.getCommonPathAncestor(newTargetString1, newTargetString2);
+        int commonLength = commonAncestor == null ? 0 : commonAncestor.length();
+
+        newTargetString1 = newTargetString1.substring(commonLength);
+        newTargetString2 = newTargetString2.substring(commonLength);
+
+        newTargetString1 = computeLabel(newTargetString, newTargetString1);
+        newTargetString2 = computeLabel(newTargetString, newTargetString2);
+
+        if (relativeToTarget != null) {
+            String relativeToPath = relativeToTarget.getPathOrUrlDecodedString();
+            String absolutePath = target.getPathOrUrlDecodedString();
+
+            String childPath = getChildPath(absolutePath, relativeToPath);
+            if (childPath == null) {
+                throwBadRelativePathException(absolutePath, relativeToPath);
+            }
+            String childPath1 = getChildPath(newTargetString1, relativeToPath);
+            if (childPath1 == null) {
+                throwBadRelativePathException(newTargetString1, relativeToPath);
+            }
+            String childPath2 = getChildPath(newTargetString2, relativeToPath);
+            if (childPath2 == null) {
+                throwBadRelativePathException(newTargetString2, relativeToPath);
+            }
+
+            displayPath = childPath;
+            newTargetString1 = childPath1;
+            newTargetString2 = childPath2;
+        }
+
         boolean showDiffHeader = !visitedPaths.contains(displayPath);
         if (showDiffHeader) {
-
-
-            if (useGitFormat) {
-                targetString1 = adjustRelativeToReposRoot(targetString1);
-                targetString2 = adjustRelativeToReposRoot(targetString2);
-            }
-
-            String newTargetString = displayPath;
-            String newTargetString1 = targetString1;
-            String newTargetString2 = targetString2;
-
-            String commonAncestor = SVNPathUtil.getCommonPathAncestor(newTargetString1, newTargetString2);
-            int commonLength = commonAncestor == null ? 0 : commonAncestor.length();
-
-            newTargetString1 = newTargetString1.substring(commonLength);
-            newTargetString2 = newTargetString2.substring(commonLength);
-
-            newTargetString1 = computeLabel(newTargetString, newTargetString1);
-            newTargetString2 = computeLabel(newTargetString, newTargetString2);
-
-            if (relativeToTarget != null) {
-                String relativeToPath = relativeToTarget.getPathOrUrlDecodedString();
-                String absolutePath = target.getPathOrUrlDecodedString();
-
-                String childPath = getChildPath(absolutePath, relativeToPath);
-                if (childPath == null) {
-                    throwBadRelativePathException(absolutePath, relativeToPath);
-                }
-                String childPath1 = getChildPath(newTargetString1, relativeToPath);
-                if (childPath1 == null) {
-                    throwBadRelativePathException(newTargetString1, relativeToPath);
-                }
-                String childPath2 = getChildPath(newTargetString2, relativeToPath);
-                if (childPath2 == null) {
-                    throwBadRelativePathException(newTargetString2, relativeToPath);
-                }
-
-                displayPath = childPath;
-                newTargetString1 = childPath1;
-                newTargetString2 = childPath2;
-            }
-
             String label1 = getLabel(newTargetString1, revision1);
             String label2 = getLabel(newTargetString2, revision2);
 
@@ -351,7 +387,7 @@ public class SvnDiffGenerator implements ISvnDiffGenerator {
         }
     }
 
-    public void displayContentChanged(SvnTarget target, File leftFile, File rightFile, String revision1, String revision2, String mimeType1, String mimeType2, SvnDiffCallback.OperationKind operation, File copyFromPath, OutputStream outputStream) throws SVNException {
+    public void displayContentChanged(SvnTarget target, File leftFile, File rightFile, String revision1, String revision2, String mimeType1, String mimeType2, SvnDiffCallback.OperationKind operation, File copyFromPath, SVNProperties originalProperties, SVNProperties propChanges, OutputStream outputStream) throws SVNException {
         if (isPropertiesOnly()) {
             return;
         }
@@ -427,9 +463,7 @@ public class SvnDiffGenerator implements ISvnDiffGenerator {
                 return;
             }
 
-
-
-            displayBinary(mimeType1, mimeType2, outputStream, leftIsBinary, rightIsBinary);
+            displayBinary(leftFile, rightFile, mimeType1, mimeType2, outputStream, leftIsBinary, rightIsBinary);
 
             return;
         }
@@ -454,22 +488,51 @@ public class SvnDiffGenerator implements ISvnDiffGenerator {
         }
     }
 
-    private void displayBinary(String mimeType1, String mimeType2, OutputStream outputStream, boolean leftIsBinary, boolean rightIsBinary) throws SVNException {
-        displayCannotDisplayFileMarkedBinary(outputStream);
+    private void displayBinary(File leftFile, File rightFile, String mimeType1, String mimeType2, OutputStream outputStream, boolean leftIsBinary, boolean rightIsBinary) throws SVNException {
+        try {
+            if (useGitFormat) {
+                displayString(outputStream, "GIT binary patch\n");
 
-        if (leftIsBinary && !rightIsBinary) {
-            displayMimeType(outputStream, mimeType1);
-        } else if (!leftIsBinary && rightIsBinary) {
-            displayMimeType(outputStream, mimeType2);
-        } else if (leftIsBinary && rightIsBinary) {
-            if (mimeType1.equals(mimeType2)) {
-                displayMimeType(outputStream, mimeType1);
+                //write right file first as base85 encoded gzipped content
+                final DeflatingInputStream rightGzipInputStream = createCompressed(rightFile);
+                try {
+                    writeLiteral(rightFile == null ? 0 : rightFile.length(), rightGzipInputStream, outputStream);
+                } finally {
+                    SVNFileUtil.closeFile(rightGzipInputStream);
+                }
+                outputStream.write('\n');
+
+                final DeflatingInputStream leftGzipInputStream = createCompressed(leftFile);
+                try {
+                    writeLiteral(leftFile == null ? 0 : leftFile.length(), leftGzipInputStream, outputStream);
+                } finally {
+                    SVNFileUtil.closeFile(leftGzipInputStream);
+                }
             } else {
-                displayMimeTypes(outputStream, mimeType1, mimeType2);
+                displayCannotDisplayFileMarkedBinary(outputStream);
+
+                if (leftIsBinary && !rightIsBinary) {
+                    displayMimeType(outputStream, mimeType1);
+                } else if (!leftIsBinary && rightIsBinary) {
+                    displayMimeType(outputStream, mimeType2);
+                } else if (leftIsBinary && rightIsBinary) {
+                    if (mimeType1.equals(mimeType2)) {
+                        displayMimeType(outputStream, mimeType1);
+                    } else {
+                        displayMimeTypes(outputStream, mimeType1, mimeType2);
+                    }
+                }
             }
+        } catch (IOException e) {
+            final SVNErrorMessage errorMessage = SVNErrorMessage.create(SVNErrorCode.IO_ERROR, e);
+            SVNErrorManager.error(errorMessage, SVNLogType.CLIENT);
         }
     }
 
+    private DeflatingInputStream createCompressed(File file) throws IOException {
+        return new DeflatingInputStream(file == null ? SVNFileUtil.DUMMY_IN : new BufferedInputStream(new FileInputStream(file)));
+    }
+
     private void internalDiff(SvnTarget target, OutputStream outputStream, String displayPath, File file1, File file2, String label1, String label2, SvnDiffCallback.OperationKind operation, String copyFromPath, String revision1, String revision2) throws SVNException {
         String header = getHeaderString(target, displayPath, file2 == null, file1 == null, operation, copyFromPath);
         if (file2 == null && !isDiffDeleted()) {
@@ -478,6 +541,7 @@ public class SvnDiffGenerator implements ISvnDiffGenerator {
             } catch (IOException e) {
                 wrapException(e);
             }
+            visitedPaths.add(displayPath);
             return;
         }
         if (file1 == null && !isDiffAdded()) {
@@ -486,6 +550,7 @@ public class SvnDiffGenerator implements ISvnDiffGenerator {
             } catch (IOException e) {
                 wrapException(e);
             }
+            visitedPaths.add(displayPath);
             return;
         }
         String headerFields = getHeaderFieldsString(target, displayPath, label1, label2, revision1, revision2, operation, copyFromPath);
@@ -517,12 +582,12 @@ public class SvnDiffGenerator implements ISvnDiffGenerator {
                 diffHeader = header + headerFields;
             }
             QDiffGenerator generator = new QDiffUniGenerator(properties, diffHeader);
-            EmptyDetectionWriter writer = new EmptyDetectionWriter(new OutputStreamWriter(outputStream, HEADER_ENCODING));
-            QDiffManager.generateTextDiff(is1, is2, null, writer, generator);
-            if (writer.isSomethingWritten()) {
+            EmptyDetectionOutputStream emptyDetectionOutputStream = new EmptyDetectionOutputStream(outputStream);
+            QDiffManager.generateTextDiff(is1, is2, emptyDetectionOutputStream, generator);
+            if (emptyDetectionOutputStream.isSomethingWritten()) {
                 visitedPaths.add(displayPath);
             }
-            writer.flush();
+            emptyDetectionOutputStream.flush();
         } catch (IOException e) {
             SVNErrorMessage err = SVNErrorMessage.create(SVNErrorCode.IO_ERROR, e.getMessage());
             SVNErrorManager.error(err, e, SVNLogType.DEFAULT);
@@ -1160,13 +1225,69 @@ public class SvnDiffGenerator implements ISvnDiffGenerator {
         return options;
     }
 
-    private class EmptyDetectionWriter extends Writer {
+    public void setCanceller(ISVNCanceller canceller) {
+        this.canceller = canceller;
+    }
 
-        private final Writer writer;
+    private void writeLiteral(long uncompressedSize, DeflatingInputStream inputStream, OutputStream outputStream) throws IOException {
+        displayString(outputStream, String.format("literal %s\n", uncompressedSize));
+
+        final byte[] chunk = new byte[52];
+
+        int bytesRead;
+        do {
+            checkCancelled();
+
+            bytesRead = 0;
+            int rd = 0;
+            do {
+                rd = inputStream.read(chunk, bytesRead, chunk.length - bytesRead);
+                if (rd < 0) {
+                    break;
+                }
+                bytesRead += rd;
+            } while (bytesRead < chunk.length);
+
+            if (bytesRead == 0) {
+                //nothing to read
+                break;
+            }
+            final char lengthChar = B85_LENGTHS_TABLE.charAt(bytesRead - 1);
+            displayString(outputStream, String.valueOf(lengthChar));
+
+            int left = bytesRead;
+            int nextOffset = 0;
+            long info = 0;
+
+            final byte[] five = new byte[5];
+
+            while (left != 0) {
+                for (int n = 24; n >= 0 && left != 0; n -= 8, nextOffset++, left--) {
+                    info |= ((long)((int)chunk[nextOffset] & 0xff)) << n;
+                }
+                for (int n = 4; n >= 0; n--) {
+                    five[n] = (byte) B85_TABLE.charAt((int) (info % 85));
+                    info /= 85;
+                }
+                outputStream.write(five);
+            }
+            outputStream.write('\n');
+        } while (bytesRead == chunk.length);
+    }
+
+    private void checkCancelled() {
+        if (canceller != null) {
+            checkCancelled();
+        }
+    }
+
+    private class EmptyDetectionOutputStream extends OutputStream {
+
+        private final OutputStream outputStream;
         private boolean somethingWritten;
 
-        public EmptyDetectionWriter(Writer writer) {
-            this.writer = writer;
+        public EmptyDetectionOutputStream(OutputStream outputStream) {
+            this.outputStream = outputStream;
             this.somethingWritten = false;
         }
 
@@ -1177,59 +1298,155 @@ public class SvnDiffGenerator implements ISvnDiffGenerator {
         @Override
         public void write(int c) throws IOException {
             somethingWritten = true;
-            writer.write(c);
+            outputStream.write(c);
         }
 
         @Override
-        public void write(char[] cbuf) throws IOException {
-            somethingWritten = cbuf.length > 0;
-            writer.write(cbuf);
+        public void write(byte[] bytes) throws IOException {
+            somethingWritten = bytes.length > 0;
+            outputStream.write(bytes);
         }
 
         @Override
-        public void write(char[] cbuf, int off, int len) throws IOException {
-            somethingWritten = len > 0 && cbuf.length > 0;
-            writer.write(cbuf, off, len);
-        }
-
-        @Override
-        public void write(String str) throws IOException {
-            somethingWritten = str.length() > 0;
-            writer.write(str);
-        }
-
-        @Override
-        public void write(String str, int off, int len) throws IOException {
-            somethingWritten = len > 0 && str.length() > 0;
-            writer.write(str, off, len);
-        }
-
-        @Override
-        public Writer append(CharSequence csq) throws IOException {
-            somethingWritten = csq.length() > 0;
-            return writer.append(csq);
-        }
-
-        @Override
-        public Writer append(CharSequence csq, int start, int end) throws IOException {
-            somethingWritten = csq.length() > 0 && (start >= end);
-            return writer.append(csq, start, end);
-        }
-
-        @Override
-        public Writer append(char c) throws IOException {
-            somethingWritten = true;
-            return writer.append(c);
+        public void write(byte[] bytes, int offset, int length) throws IOException {
+            somethingWritten = length > 0;
+            outputStream.write(bytes, offset, length);
         }
 
         @Override
         public void flush() throws IOException {
-            writer.flush();
+            outputStream.flush();
         }
 
         @Override
         public void close() throws IOException {
-            writer.close();
+            outputStream.close();
+        }
+    }
+
+    private static class DeflatingInputStream extends InputStream {
+
+        private final InputStream inputStream;
+        private final byte[] uncompressed;
+        private final byte[] compressed;
+        private int compressedOffset;
+        private int compressedLength;
+        private final byte[] singleByteBuffer;
+        private final DeflaterOutputStream deflaterOutputStream;
+        private boolean finished;
+
+        private DeflatingInputStream(InputStream inputStream) throws IOException {
+            this.inputStream = inputStream;
+            this.uncompressed = new byte[1024];
+            this.compressed = new byte[16384];
+            this.compressedOffset = 0;
+            this.compressedLength = 0;
+            this.singleByteBuffer = new byte[1];
+            this.deflaterOutputStream = createCompressingOutputStream();
+        }
+
+        private DeflaterOutputStream createCompressingOutputStream() throws IOException {
+            return new DeflaterOutputStream(new OutputStream() {
+                @Override
+                public void write(int b) throws IOException {
+                    if (compressedOffset + compressedLength == compressed.length) {
+                        //no space available
+                        throwNoSpaceAvailable();
+                    } else {
+                        compressed[compressedOffset + compressedLength] = (byte) b;
+                        compressedLength++;
+                    }
+                }
+
+                @Override
+                public void write(byte[] b) throws IOException {
+                    write(b, 0, b.length);
+                }
+
+                @Override
+                public void write(byte[] b, int off, int len) throws IOException {
+                    if (compressedOffset + compressedLength + len > compressed.length) {
+                        throwNoSpaceAvailable();
+                    } else {
+                        System.arraycopy(b, off, compressed, compressedOffset, len);
+                        compressedLength += len;
+                    }
+                }
+
+                private void throwNoSpaceAvailable() throws IOException {
+                    throw new IOException("No space available in the compressed data buffer");
+                }
+            });
+        }
+
+        @Override
+        public int read() throws IOException {
+            final int read = read(singleByteBuffer, 0, 1);
+            if (read < 0) {
+                return read;
+            } else {
+                return singleByteBuffer[0] & 0xff;
+            }
+        }
+
+        @Override
+        public int read(byte[] b) throws IOException {
+            return read(b, 0, b.length);
+        }
+
+        @Override
+        public int read(byte[] b, int off, int len) throws IOException {
+            if (finished) {
+                return -1;
+            }
+            while (compressedLength == 0) {
+                final int uncompressedLength = inputStream.read(uncompressed);
+                if (uncompressedLength < 0) {
+                    //input data finished
+                    deflaterOutputStream.finish();
+                    break;
+                } else {
+                    //this will fill compressed array
+                    deflaterOutputStream.write(uncompressed, 0, uncompressedLength);
+                }
+            }
+
+            if (compressedLength > 0) {
+                //use already buffered data
+                int readLength = Math.min(len, compressedLength);
+                System.arraycopy(compressed, compressedOffset, b, off, readLength);
+                compressedLength -= readLength;
+
+                if (compressedLength == 0) {
+                    compressedOffset = 0;
+                } else {
+                    compressedOffset += readLength;
+                }
+                return readLength;
+            } else {
+                finished = true;
+                return -1;
+            }
+        }
+
+        private void moveCompressedDataToBeginning() {
+            System.arraycopy(compressed, compressedOffset, compressed, 0, compressedLength);
+            compressedOffset = 0;
+        }
+
+        @Override
+        public void close() throws IOException {
+            inputStream.close();
+        }
+
+        @Override
+        public void reset() throws IOException {
+            inputStream.reset();
+        }
+
+        @Override
+        public boolean markSupported() {
+            return inputStream.markSupported();
         }
     }
 }
