@@ -8,6 +8,7 @@ import org.junit.Assume;
 import org.junit.Test;
 import org.tmatesoft.svn.core.SVNCommitInfo;
 import org.tmatesoft.svn.core.SVNDepth;
+import org.tmatesoft.svn.core.SVNErrorCode;
 import org.tmatesoft.svn.core.SVNException;
 import org.tmatesoft.svn.core.SVNLogEntry;
 import org.tmatesoft.svn.core.SVNLogEntryPath;
@@ -20,7 +21,11 @@ import org.tmatesoft.svn.core.internal.wc17.SVNWCContext;
 import org.tmatesoft.svn.core.internal.wc17.db.Structure;
 import org.tmatesoft.svn.core.internal.wc17.db.StructureFields;
 import org.tmatesoft.svn.core.internal.wc2.SvnWcGeneration;
+import org.tmatesoft.svn.core.io.ISVNEditor;
+import org.tmatesoft.svn.core.io.SVNRepository;
+import org.tmatesoft.svn.core.io.SVNRepositoryFactory;
 import org.tmatesoft.svn.core.wc.DefaultSVNCommitHandler;
+import org.tmatesoft.svn.core.wc.DefaultSVNRepositoryPool;
 import org.tmatesoft.svn.core.wc.SVNClientManager;
 import org.tmatesoft.svn.core.wc.SVNCommitClient;
 import org.tmatesoft.svn.core.wc.SVNCommitItem;
@@ -94,14 +99,14 @@ public class CommitTest {
             
             final File path = workingCopy.getFile("trunk/ext/file");
             SVNCommitClient ci = SVNClientManager.newInstance().getCommitClient();
-            final SVNCommitInfo info = ci.doCommit(new File[] {path}, 
-                    false, 
+            final SVNCommitInfo info = ci.doCommit(new File[]{path},
+                    false,
                     "message", null, null, false, true, SVNDepth.INFINITY);
             Assert.assertNotNull(info);
             Assert.assertEquals(2, info.getNewRevision());
 
-            final SVNCommitInfo info2 = ci.doCommit(new File[] {path}, 
-                    false, 
+            final SVNCommitInfo info2 = ci.doCommit(new File[]{path},
+                    false,
                     "message", null, null, false, true, SVNDepth.INFINITY);
             Assert.assertNotNull(info2);
             Assert.assertEquals(-1, info2.getNewRevision());
@@ -441,6 +446,161 @@ public class CommitTest {
         }
     }
 
+    @Test
+    public void testConflictOnRemovingNonExistentProperty() throws Exception {
+        //SVNKIT-694
+        final TestOptions testOptions = TestOptions.getInstance();
+
+        final Sandbox sandbox = Sandbox.createWithCleanup(getTestName() + ".testConflictOnRemovingNonExistentProperty", testOptions);
+
+        final SvnOperationFactory operationFactory = new SvnOperationFactory();
+        try {
+            final SVNURL url = sandbox.createSvnRepository();
+
+            final CommitBuilder commitBuilder = new CommitBuilder(url);
+            commitBuilder.addFile("trunk/conf/conf/file");
+            commitBuilder.commit();
+
+            final File workingCopy = sandbox.createDirectory("wc");
+
+            final SvnCheckout checkout = operationFactory.createCheckout();
+            checkout.setSingleTarget(SvnTarget.fromFile(workingCopy));
+            checkout.setSource(SvnTarget.fromURL(url.appendPath("trunk/conf", false)));
+            checkout.run();
+
+            final File newFile = new File(workingCopy, "conf/newFile");
+            Assert.assertTrue(newFile.createNewFile());
+
+            final SvnScheduleForAddition scheduleForAddition = operationFactory.createScheduleForAddition();
+            scheduleForAddition.setSingleTarget(SvnTarget.fromFile(newFile));
+            scheduleForAddition.run();
+
+            final DefaultSVNRepositoryPool svnRepositoryPool = new DefaultSVNRepositoryPool(null, null);
+            try {
+                final SVNRepository svnRepository = svnRepositoryPool.createRepository(url, true);
+
+                final ISVNEditor commitEditor = svnRepository.getCommitEditor("", null);
+                commitEditor.openRoot(1);
+                commitEditor.openDir("trunk", 1);
+                commitEditor.changeDirProperty("custom:lock", null);
+
+                final SvnCommit commit = operationFactory.createCommit();
+                commit.setSingleTarget(SvnTarget.fromFile(workingCopy.getAbsoluteFile()));
+                commit.run();
+
+                commitEditor.openDir("trunk/conf", 1);
+                commitEditor.openDir("trunk/conf/conf", 1);
+                commitEditor.addDir("trunk/conf/conf/dir", null, -1);
+                commitEditor.closeDir();
+                commitEditor.closeDir();
+                commitEditor.closeDir();
+                commitEditor.closeDir();
+                commitEditor.closeDir();
+                try {
+                    commitEditor.closeEdit();
+                    Assert.fail("An exception should be thrown");
+                } catch (SVNException e) {
+                    //expected
+                    e.printStackTrace();
+                    Assert.assertEquals(SVNErrorCode.FS_CONFLICT, e.getErrorMessage().getErrorCode());
+                }
+            } finally {
+                svnRepositoryPool.dispose();
+            }
+        } finally {
+            operationFactory.dispose();
+            sandbox.dispose();
+        }
+    }
+    @Test
+    public void testEmptyCommitPacketWithOtherPackets() throws Exception {
+        //SVNKIT-358
+        final TestOptions testOptions = TestOptions.getInstance();
+
+        final Sandbox sandbox = Sandbox.createWithCleanup(getTestName() + ".testEmptyCommitPacketWithOtherPackets", testOptions);
+
+        final SvnOperationFactory operationFactory = new SvnOperationFactory();
+        try {
+            final SVNURL url = sandbox.createSvnRepository();
+
+            final CommitBuilder commitBuilder = new CommitBuilder(url);
+            commitBuilder.addFile("file1");
+            commitBuilder.addFile("file2");
+            commitBuilder.commit();
+
+            final WorkingCopy workingCopy = sandbox.checkoutNewWorkingCopy(url);
+            final File workingCopyDirectory = workingCopy.getWorkingCopyDirectory();
+
+            final File file1 = workingCopy.getFile("file1");
+            final File file2 = workingCopy.getFile("file2");
+            TestUtil.writeFileContentsString(file1, "changed");
+            TestUtil.writeFileContentsString(file2, "changed");
+
+            final SVNClientManager clientManager = SVNClientManager.newInstance();
+            try {
+                final SVNCommitClient commitClient = clientManager.getCommitClient();
+                final SVNCommitPacket[] commitPackets = commitClient.doCollectCommitItems(new File[]{workingCopyDirectory}, false, false, SVNDepth.INFINITY, false, new String[0]);
+                Assert.assertEquals(1, commitPackets.length);
+
+                commitClient.doCommit(new SVNCommitPacket[]{SVNCommitPacket.EMPTY, commitPackets[0]}, false, "Commit message");
+            } finally {
+                clientManager.dispose();
+            }
+            final SVNRepository svnRepository = SVNRepositoryFactory.create(url);
+            try {
+                final long latestRevision = svnRepository.getLatestRevision();
+                Assert.assertEquals(2, latestRevision);
+            } finally {
+                svnRepository.closeSession();
+            }
+        } finally {
+            operationFactory.dispose();
+            sandbox.dispose();
+        }
+    }
+
+    @Test
+    public void testCommitEmptyPacket() throws Exception {
+        //SVNKIT-358
+        final SVNClientManager clientManager = SVNClientManager.newInstance();
+        try {
+            final SVNCommitClient commitClient = clientManager.getCommitClient();
+            commitClient.doCommit(SVNCommitPacket.EMPTY, false, "Commit message");
+            commitClient.doCommit(new SVNCommitPacket[]{}, false, "Commit message");
+            commitClient.doCommit(new SVNCommitPacket[]{SVNCommitPacket.EMPTY}, false, "Commit message");
+            commitClient.doCommit(new SVNCommitPacket[]{SVNCommitPacket.EMPTY, SVNCommitPacket.EMPTY}, false, "Commit message");
+            //no exception should be thrown
+        } finally {
+            clientManager.dispose();
+        }
+    }
+
+    @Test
+    public void testDotDotInPath() throws Exception {
+        final TestOptions testOptions = TestOptions.getInstance();
+
+        final Sandbox sandbox = Sandbox.createWithCleanup(getTestName() + ".testDotDotInPath", testOptions);
+
+        final SvnOperationFactory operationFactory = new SvnOperationFactory();
+        try {
+            final SVNURL url = sandbox.createSvnRepository();
+
+            final CommitBuilder commitBuilder = new CommitBuilder(url);
+            commitBuilder.addFile("../file");
+            try {
+                commitBuilder.commit();
+                Assert.fail("An exception should be thrown");
+            } catch (SVNException e) {
+                //expected
+                Assert.assertEquals(SVNErrorCode.FS_PATH_SYNTAX, e.getErrorMessage().getErrorCode());
+                Assert.assertTrue(e.getMessage().contains("Path '/..' contains . or .. element"));
+            }
+        } finally {
+            operationFactory.dispose();
+            sandbox.dispose();
+        }
+    }
+
     private void setIncomplete(SvnOperationFactory svnOperationFactory, File path, long revision, File reposRelpath) throws SVNException {
         SVNWCContext context = new SVNWCContext(svnOperationFactory.getOptions(), svnOperationFactory.getEventHandler());
         try {
