@@ -1,23 +1,45 @@
 package org.tmatesoft.svn.test;
 
-import org.junit.Assert;
-import org.junit.Assume;
-import org.junit.Ignore;
-import org.junit.Test;
-import org.tmatesoft.svn.core.*;
-import org.tmatesoft.svn.core.internal.util.SVNPathUtil;
-import org.tmatesoft.svn.core.internal.wc.DefaultSVNOptions;
-import org.tmatesoft.svn.core.internal.wc.SVNFileUtil;
-import org.tmatesoft.svn.core.internal.wc2.ng.SvnDiffGenerator;
-import org.tmatesoft.svn.core.wc.*;
-import org.tmatesoft.svn.core.wc2.*;
-
 import java.io.ByteArrayOutputStream;
 import java.io.File;
 import java.io.OutputStream;
 import java.util.ArrayList;
 import java.util.List;
 
+import org.junit.Assert;
+import org.junit.Assume;
+import org.junit.Ignore;
+import org.junit.Test;
+import org.tmatesoft.svn.core.SVNCommitInfo;
+import org.tmatesoft.svn.core.SVNDepth;
+import org.tmatesoft.svn.core.SVNException;
+import org.tmatesoft.svn.core.SVNProperties;
+import org.tmatesoft.svn.core.SVNProperty;
+import org.tmatesoft.svn.core.SVNPropertyValue;
+import org.tmatesoft.svn.core.SVNURL;
+import org.tmatesoft.svn.core.internal.util.SVNPathUtil;
+import org.tmatesoft.svn.core.internal.wc.DefaultSVNOptions;
+import org.tmatesoft.svn.core.internal.wc.SVNFileUtil;
+import org.tmatesoft.svn.core.internal.wc2.ng.SvnDiffGenerator;
+import org.tmatesoft.svn.core.wc.DefaultSVNDiffGenerator;
+import org.tmatesoft.svn.core.wc.DefaultSVNRepositoryPool;
+import org.tmatesoft.svn.core.wc.ISVNDiffGenerator;
+import org.tmatesoft.svn.core.wc.SVNClientManager;
+import org.tmatesoft.svn.core.wc.SVNDiffClient;
+import org.tmatesoft.svn.core.wc.SVNRevision;
+import org.tmatesoft.svn.core.wc.SVNStatusType;
+import org.tmatesoft.svn.core.wc.SVNWCUtil;
+import org.tmatesoft.svn.core.wc2.ISvnObjectReceiver;
+import org.tmatesoft.svn.core.wc2.SvnCheckout;
+import org.tmatesoft.svn.core.wc2.SvnCopy;
+import org.tmatesoft.svn.core.wc2.SvnCopySource;
+import org.tmatesoft.svn.core.wc2.SvnDiff;
+import org.tmatesoft.svn.core.wc2.SvnDiffStatus;
+import org.tmatesoft.svn.core.wc2.SvnDiffSummarize;
+import org.tmatesoft.svn.core.wc2.SvnOperationFactory;
+import org.tmatesoft.svn.core.wc2.SvnScheduleForRemoval;
+import org.tmatesoft.svn.core.wc2.SvnTarget;
+
 @Ignore
 public class DiffTest {
 
@@ -973,6 +995,200 @@ public class DiffTest {
         }
     }
 
+    @Test
+    public void testDiffSummarizeBinaryPropertyAdded() throws Exception {
+        final TestOptions options = TestOptions.getInstance();
+
+        final SvnOperationFactory svnOperationFactory = new SvnOperationFactory();
+        final Sandbox sandbox = Sandbox.createWithCleanup(getTestName() + ".testDiffSummarizeBinaryPropertyAdded", options);
+        try {
+            final SVNURL url = sandbox.createSvnRepository();
+
+            final CommitBuilder commitBuilder1 = new CommitBuilder(url);
+            commitBuilder1.addFile("file");
+            commitBuilder1.commit();
+
+            final CommitBuilder commitBuilder2 = new CommitBuilder(url);
+            commitBuilder2.setFileProperty("file", "binaryPropertyName",
+                    SVNPropertyValue.create("binaryPropertyName", new byte[]{-1}));
+            commitBuilder2.commit();
+
+            final List<SvnDiffStatus> statuses = new ArrayList<SvnDiffStatus>();
+            final SvnDiffSummarize diffSummarize = svnOperationFactory.createDiffSummarize();
+            diffSummarize.setSources(
+                    SvnTarget.fromURL(url, SVNRevision.create(1)),
+                    SvnTarget.fromURL(url, SVNRevision.create(2)));
+            diffSummarize.setReceiver(new ISvnObjectReceiver<SvnDiffStatus>() {
+                public void receive(SvnTarget target, SvnDiffStatus status) throws SVNException {
+                    statuses.add(status);
+                }
+            });
+            diffSummarize.run();
+            Assert.assertEquals(1, statuses.size());
+            final SvnDiffStatus status = statuses.get(0);
+            Assert.assertTrue(status.isPropertiesModified());
+            Assert.assertEquals(SVNStatusType.STATUS_NORMAL, status.getModificationType());
+            Assert.assertEquals("file", status.getPath());
+        } finally {
+            svnOperationFactory.dispose();
+            sandbox.dispose();
+        }
+    }
+
+    @Test
+    public void testDiffBinaryFilesBase85() throws Exception {
+        final TestOptions options = TestOptions.getInstance();
+
+        final SvnOperationFactory svnOperationFactory = new SvnOperationFactory();
+        final Sandbox sandbox = Sandbox.createWithCleanup(getTestName() + ".testDiffBinaryFilesBase85", options);
+        try {
+            final SVNURL url = sandbox.createSvnRepository();
+            System.out.println("url = " + url);
+
+            final CommitBuilder commitBuilder1 = new CommitBuilder(url);
+            commitBuilder1.addFile("file", new byte[]{1, 2, 3, 4, 5, 6, 7, 8});
+            commitBuilder1.setFileProperty("file", SVNProperty.MIME_TYPE, SVNPropertyValue.create("application/octet-stream"));
+            commitBuilder1.commit();
+
+            final CommitBuilder commitBuilder2 = new CommitBuilder(url);
+            commitBuilder2.changeFile("file", new byte[]{9, 10, 11, 12, 13, 14, 15});
+            commitBuilder2.commit();
+
+            final SvnDiffGenerator diffGenerator = new SvnDiffGenerator();
+            diffGenerator.setUseGitFormat(true);
+            diffGenerator.setBasePath(new File(""));
+            
+            final ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
+
+            final SvnDiff diff = svnOperationFactory.createDiff();
+            diff.setSources(SvnTarget.fromURL(url, SVNRevision.create(1)), SvnTarget.fromURL(url, SVNRevision.create(2)));
+            diff.setOutput(byteArrayOutputStream);
+            diff.setDiffGenerator(diffGenerator);
+            diff.setUseGitDiffFormat(true);
+            diff.run();
+
+            Assert.assertEquals(
+                    "Index: file\n" +
+                    "===================================================================\n" +
+                    "diff --git a/file b/file\n" +
+                    "GIT binary patch\n" +
+                    "literal 7\n" +
+                    "Oc%0+p;^yJy;|Bl%I{;Mx\n" +
+                    "\n" +
+                    "literal 8\n" +
+                    "Pc${NoVrF4wW9I+>0Du4`\n", byteArrayOutputStream.toString());
+
+        } finally {
+            svnOperationFactory.dispose();
+            sandbox.dispose();
+        }
+    }
+
+    @Test
+    public void testChangeFileToSymlink() throws Exception {
+        Assume.assumeTrue(SVNFileUtil.symlinksSupported());
+        final TestOptions options = TestOptions.getInstance();
+
+        final SvnOperationFactory svnOperationFactory = new SvnOperationFactory();
+        final Sandbox sandbox = Sandbox.createWithCleanup(getTestName() + ".testChangeFileToSymlink", options);
+        try {
+            final SVNURL url = sandbox.createSvnRepository();
+
+            final CommitBuilder commitBuilder = new CommitBuilder(url);
+            commitBuilder.addFile("trunk/symlink", "link some/path".getBytes());
+            commitBuilder.commit();
+
+            final SVNURL trunkUrl = url.appendPath("trunk", false);
+
+            final File workingCopyDirectory = sandbox.createDirectory("wc");
+            final SvnCheckout checkout = svnOperationFactory.createCheckout();
+            checkout.setSource(SvnTarget.fromURL(trunkUrl));
+            checkout.setSingleTarget(SvnTarget.fromFile(workingCopyDirectory));
+            checkout.run();
+
+            final File symlink = new File(workingCopyDirectory, "symlink");
+            SVNFileUtil.deleteFile(symlink);
+            SVNFileUtil.createSymlink(symlink, "changed/path");
+
+            final SvnDiffGenerator diffGenerator = new SvnDiffGenerator();
+            diffGenerator.setBasePath(new File("").getAbsoluteFile());
+            diffGenerator.setUseGitFormat(true);
+            diffGenerator.setIgnoreProperties(false);
+            final ByteArrayOutputStream output = new ByteArrayOutputStream();
+
+            final SvnDiff diff = svnOperationFactory.createDiff();
+            diff.setSources(SvnTarget.fromURL(trunkUrl, SVNRevision.HEAD),
+                    SvnTarget.fromFile(workingCopyDirectory, SVNRevision.WORKING));
+            diff.setDiffGenerator(diffGenerator);
+            diff.setUseGitDiffFormat(true);
+            diff.setOutput(output);
+            diff.run();
+
+            final String patchString = output.toString();
+
+            Assert.fail("TODO: complete the test");
+        } finally {
+            svnOperationFactory.dispose();
+            sandbox.dispose();
+        }
+    }
+
+    @Ignore("Currently fails")
+    @Test
+    public void testDiffDeletedDirectoryAndFile() throws Exception {
+        final TestOptions options = TestOptions.getInstance();
+
+        final SvnOperationFactory svnOperationFactory = new SvnOperationFactory();
+        final Sandbox sandbox = Sandbox.createWithCleanup(getTestName() + ".testDiffDeletedDirectoryAndFile", options);
+        try {
+            final SVNURL url = sandbox.createSvnRepository();
+
+            final CommitBuilder commitBuilder = new CommitBuilder(url);
+            commitBuilder.addDirectory("deletedDirectory");
+            commitBuilder.addFile("deletedFile");
+            commitBuilder.setDirectoryProperty("deletedDirectory", SVNProperty.IGNORE, SVNPropertyValue.create("*"));
+            commitBuilder.setFileProperty("deletedFile", "propName", SVNPropertyValue.create("propValue"));
+            commitBuilder.commit();
+
+            final File workingCopyDirectory = sandbox.createDirectory("wc");
+            final File deletedDirectory = new File(workingCopyDirectory, "deletedDirectory");
+            final File deletedFile = new File(workingCopyDirectory, "deletedFile");
+
+            final SvnCheckout checkout = svnOperationFactory.createCheckout();
+            checkout.setSource(SvnTarget.fromURL(url));
+            checkout.setSingleTarget(SvnTarget.fromFile(workingCopyDirectory));
+            checkout.run();
+
+            final SvnScheduleForRemoval scheduleForRemoval = svnOperationFactory.createScheduleForRemoval();
+            scheduleForRemoval.addTarget(SvnTarget.fromFile(deletedDirectory));
+            scheduleForRemoval.addTarget(SvnTarget.fromFile(deletedFile));
+            scheduleForRemoval.run();
+
+            final SvnDiffGenerator diffGenerator = new SvnDiffGenerator();
+            diffGenerator.setBasePath(new File("").getAbsoluteFile());
+            diffGenerator.setUseGitFormat(true);
+            diffGenerator.setIgnoreProperties(false);
+            final ByteArrayOutputStream output = new ByteArrayOutputStream();
+
+            final SvnDiff diff = svnOperationFactory.createDiff();
+            diff.setSources(SvnTarget.fromURL(url, SVNRevision.HEAD),
+                    SvnTarget.fromFile(workingCopyDirectory, SVNRevision.WORKING));
+            diff.setDiffGenerator(diffGenerator);
+            diff.setUseGitDiffFormat(true);
+            diff.setOutput(output);
+            diff.run();
+
+            final String patchString = output.toString();
+
+//            System.out.println("patchString = " + patchString);
+
+            throw new UnsupportedOperationException("TODO: complete the test");
+        } finally {
+            svnOperationFactory.dispose();
+            sandbox.dispose();
+        }
+    }
+
     private void diffFiles(SVNURL url, final SVNRevision fromVersion, final SVNRevision toVersion, final ISVNDiffGenerator diffGenerator) throws SVNException {
         DefaultSVNOptions options = SVNWCUtil.createDefaultOptions(true);
         final DefaultSVNRepositoryPool pool = new DefaultSVNRepositoryPool(SVNWCUtil.createDefaultAuthenticationManager(), options);
